program JSCS_benchmarking
disp _newline(100)  
dis as text "The figures for the Global Benchmarking Analysis are being prepared. Please wait."

quietly {
set graphics off
local years "$years"
disp `years'
local target `" "$target_country" "'
local structural `" "$structural_comparators" "'
local aspirational `" "$aspirational_comparators" "'
local dataset `" "$na_data" "'
disp `target'
disp `structural'
disp `aspirational'
disp `dataset'

confirmdir "$output\Global Benchmarking Analysis"
if _rc != 0 {
                mkdir "$output\Global Benchmarking Analysis"
                di "Country folder created"
				}
else {
                di "Country folder already exists"
                }
local fig=0
*Figure : International benchmarking of structural features - employment shares across sectors
preserve
use "$data\GlobalBenchmarking_$target_country.dta", clear
collapse (mean) empl_share_agr empl_share_ind empl_share_ser, by(country iso3 year)
reshape long empl_share_, i(country iso3 year) j(sector) string
rename  empl_share_ empl_share
egen sector_id=group(sector)
sort sector_id
by sector_id: egen med = median(empl_share)
by sector_id: egen lqt = pctile(empl_share), p(25)
by sector_id: egen uqt = pctile(empl_share), p(75)
by sector_id: egen sd  = sd(empl_share)
by sector_id: egen iqr = iqr(empl_share)
by sector_id: egen mean = mean(empl_share)
by sector_id: egen ls = min(max(empl_share, mean-2*sd))
by sector_id: egen us = max(min(empl_share, mean+2*sd))
egen help1=min(empl_share), by(sector_id)
egen help2=max(empl_share), by(sector_id)
replace ls=help1 if help1>ls
replace us=help2 if help2<us
levelsof year if iso3=="$target_country", local(year)
egen year_max=max(year) if iso3=="$target_country"
levelsof year_max, local(year_max)
twoway rbar lqt med sector_id, pstyle(p2) barw(.5) || ///
       rbar med uqt sector_id, pstyle(p2) barw(.5) || ///
       rspike lqt ls sector_id, pstyle(p2) || ///
       rspike uqt us sector_id, pstyle(p2) || ///
       rcap ls ls sector_id, msize(*6) pstyle(p2) || ///
       rcap us us sector_id, msize(*6) pstyle(p2) || ///
	   scatter empl_share sector_id if iso3=="$target_country", msymbol(Oh) msize(*2) mcolor("0 35 69") legend(order(5 "$target_country - `year'")) ///
	   xlabel( 1 "agriculture" 2 "industry" 3 "services") ytitle("share in total employment") xtitle("") ///
	   graphregion(color(white)) ///
	   note("Explanatory note: Blue boxes capture interquartile range around means and extremes equal mean +/- two times s.d." "Benchmarking sample: Includes all country-year observations since 1991 with the same p.c. GDP (in US$ 2017 PPP) as in $target_country in `year_max'", height(6) span size(vsmall)) ///
	   caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Global Benchmarking Analysis\BenchmarkingAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore	  
*Figure : International benchmarking of structural features - value added shares across sectors
preserve
use "$data\GlobalBenchmarking_$target_country.dta", clear
collapse (mean) gdp_share_curr_agr gdp_share_curr_ind gdp_share_curr_ser, by(country iso3 year)
reshape long gdp_share_, i(country iso3 year) j(sector) string
rename  gdp_share_ gdp_share
egen sector_id=group(sector)
sort sector_id
by sector_id: egen med = median(gdp_share)
by sector_id: egen lqt = pctile(gdp_share), p(25)
by sector_id: egen uqt = pctile(gdp_share), p(75)
by sector_id: egen sd  = sd(gdp_share)
by sector_id: egen iqr = iqr(gdp_share)
by sector_id: egen mean = mean(gdp_share)
by sector_id: egen ls = min(max(gdp_share, mean-2*sd))
by sector_id: egen us = max(min(gdp_share, mean+2*sd))
egen help1=min(gdp_share), by(sector_id)
egen help2=max(gdp_share), by(sector_id)
replace ls=help1 if help1>ls
replace us=help2 if help2<us
levelsof year if iso3=="$target_country", local(year)
egen year_max=max(year) if iso3=="$target_country"
levelsof year_max, local(year_max)
twoway rbar lqt med sector_id, pstyle(p2) barw(.5) || ///
       rbar med uqt sector_id, pstyle(p2) barw(.5) || ///
       rspike lqt ls sector_id, pstyle(p2) || ///
       rspike uqt us sector_id, pstyle(p2) || ///
       rcap ls ls sector_id, msize(*6) pstyle(p2) || ///
       rcap us us sector_id, msize(*6) pstyle(p2) || ///
	   scatter gdp_share sector_id if iso3=="$target_country", msymbol(Oh) msize(*2) mcolor("0 35 69") legend(order(5 "$target_country - `year'")) ///
	   xlabel( 1 "agriculture" 2 "industry" 3 "services") ytitle("share in total value added") xtitle("") ///
	   graphregion(color(white)) ///
	   note("Explanatory note: Blue boxes capture interquartile range around means and extremes equal mean +/- two times s.d." "Benchmarking sample: Includes all country-year observations since 1991 with the same p.c. GDP (in US$ 2017 PPP) as in $target_country in `year_max'", height(6) span size(vsmall)) ///
	   caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall))
local fig=`fig'+1
graph export "$output\Global Benchmarking Analysis\BenchmarkingAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore	  

*Figure: International benchmarking of structural features - value added per worker
{
preserve
use "$data\GlobalBenchmarking_$target_country.dta", clear
gen pwgdp_ppp_cons_all=gdp_ppp_cons_usd/pop_empl
gen pwgdp_ppp_cons_agr=(gdp_ppp_cons_usd*gdp_share_curr_agr)/pop_empl_agr
gen pwgdp_ppp_cons_ind=(gdp_ppp_cons_usd*gdp_share_curr_ind)/pop_empl_ind
gen pwgdp_ppp_cons_ser=(gdp_ppp_cons_usd*gdp_share_curr_ser)/pop_empl_ser

collapse (mean) pwgdp_ppp_cons_all pwgdp_ppp_cons_agr pwgdp_ppp_cons_ind pwgdp_ppp_cons_ser, by(country iso3 year)

reshape long pwgdp_ppp_cons_, i(country iso3 year) j(sector) string
rename  pwgdp_ppp_cons_ pwgdp_ppp_cons
replace pwgdp_ppp_cons=ln(pwgdp_ppp_cons)
egen sector_id=group(sector)
replace sector_id=1 if sector=="all"
replace sector_id=2 if sector=="agr"
sort sector_id
by sector_id: egen med = median(pwgdp_ppp_cons)
by sector_id: egen lqt = pctile(pwgdp_ppp_cons), p(25)
by sector_id: egen uqt = pctile(pwgdp_ppp_cons), p(75)
by sector_id: egen sd  = sd(pwgdp_ppp_cons)
by sector_id: egen iqr = iqr(pwgdp_ppp_cons)
by sector_id: egen mean = mean(pwgdp_ppp_cons)
by sector_id: egen ls = min(max(pwgdp_ppp_cons, mean-2*sd))
by sector_id: egen us = max(min(pwgdp_ppp_cons, mean+2*sd))
egen help1=min(pwgdp_ppp_cons), by(sector_id)
egen help2=max(pwgdp_ppp_cons), by(sector_id)
replace ls=help1 if help1>ls
replace us=help2 if help2<us
levelsof year if iso3=="$target_country", local(year)
egen year_max=max(year) if iso3=="$target_country"
levelsof year_max, local(year_max)
twoway rbar lqt med sector_id, pstyle(p2) barw(.5) || ///
       rbar med uqt sector_id, pstyle(p2) barw(.5) || ///
       rspike lqt ls sector_id, pstyle(p2) || ///
       rspike uqt us sector_id, pstyle(p2) || ///
       rcap ls ls sector_id, msize(*6) pstyle(p2) || ///
       rcap us us sector_id, msize(*6) pstyle(p2) || ///
	   scatter pwgdp_ppp_cons sector_id if iso3=="$target_country", msymbol(Oh) msize(*2) mcolor("0 35 69") legend(order(5 "$target_country - `year'")) ///
	   xlabel( 1 "econ.-wide" 2 "agriculture" 3 "industry" 4 "services") ytitle("per worker value added," "in PPP 2017 constant prices (log scale)") xtitle("") ///
	   graphregion(color(white)) ///
	   note("Explanatory note: Blue boxes capture interquartile range around means and extremes equal mean +/- two times s.d." "Benchmarking sample: Includes all country-year observations since 1991 with the same p.c. GDP (in US$ 2017 PPP) as in $target_country in `year_max'", height(6) span size(vsmall)) ///
	   caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall))
local fig=`fig'+1
graph export "$output\Global Benchmarking Analysis\BenchmarkingAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore	   
}

*Figure: International benchmarking of structural features - Labor market indicators 
preserve
use "$data\GlobalBenchmarking_$target_country.dta", clear
gen rate_lfp=lfp_rate
gen rate_emp=empl_rate
gen rate_wempl=empl_share_wge
gen rate_urb=pop_share_urb/100
collapse (mean) rate_lfp rate_emp rate_wempl rate_urb, by(country iso3 year)
reshape long rate_, i(country iso3 year) j(type) string
rename  rate_ rate
gen type_id=1 if type=="lfp"
replace type_id=2 if type=="emp"
replace type_id=3 if type=="wempl"
replace type_id=4 if type=="urb"
sort type_id
by type_id: egen med = median(rate)
by type_id: egen lqt = pctile(rate), p(25)
by type_id: egen uqt = pctile(rate), p(75)
by type_id: egen sd  = sd(rate)
by type_id: egen iqr = iqr(rate)
by type_id: egen mean = mean(rate)
by type_id: egen ls = min(max(rate, mean-2*sd))
by type_id: egen us = max(min(rate, mean+2*sd))
egen help1=min(rate), by(type_id)
egen help2=max(rate), by(type_id)
replace ls=help1 if help1>ls
replace us=help2 if help2<us
levelsof year if iso3=="$target_country", local(year)
egen year_max=max(year) if iso3=="$target_country"
levelsof year_max, local(year_max)
twoway rbar lqt med type_id, pstyle(p2) barw(.5) || ///
       rbar med uqt type_id, pstyle(p2) barw(.5) || ///
       rspike lqt ls type_id, pstyle(p2) || ///
       rspike uqt us type_id, pstyle(p2) || ///
       rcap ls ls type_id, msize(*6) pstyle(p2) || ///
       rcap us us type_id, msize(*6) pstyle(p2) || ///
	   scatter rate type_id if iso3=="$target_country", msymbol(Oh) msize(*2) mcolor("0 35 69") legend(order(5 "$target_country - `year'")) ///
	   xlabel( 1 "lfp" 2 "emp" 3 "wempl" 4 "urb") ytitle("rate") xtitle("")  ///
	   graphregion(color(white)) ///
	   note("Explanatory note: Blue boxes capture interquartile range around means and extremes equal mean +/- two times s.d." "Benchmarking sample: Includes all country-year observations since 1991 with the same p.c. GDP (in US$ 2017 PPP) as in $target_country in `year_max'", height(6) span size(vsmall)) ///
	   caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Global Benchmarking Analysis\BenchmarkingAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
set graphics on
graph close
clear
}

disp _newline(100)  
dis as result "All figures for the Global Benchmarking Analysis were prepared successfully."
disp _newline(1)  
dis as result "To continue you have the following options:"
disp _newline(1)
dis as result "Option 1:"
dis as text  "Global benchmarking analysis of structural features of "`target'"'s economy. In the STATA Command Window below, please type:" 
disp as result "JSCS_benchmarking"
disp as text "and press enter."
disp _newline(1)
dis as result "Option 2:"
dis as text  "Growth episodes analysis for "`target'". In the STATA Command Window below, please type:"
disp as result "JSCS_episodes"
disp as text "and press enter."
disp _newline(1)
dis as result "Option 3:"
dis as text  "Growth episodes analysis for "`target'" versus structural and aspirational peers. In the STATA Command Window below, please type: "
disp as result "JSCS_comparisons"
disp as text "and press enter."
end 
