program JSCS_comparisons
disp _newline(100)  
dis as text "The figures for the Growth Episodes Country Comparison Analysis are being prepared. Please wait. "


quietly {
set graphics off
local years "$years"
disp `years'
local target `" "$target_country" "'
local structural `" "$structural_comparators" "'
local aspirational `" "$aspirational_comparators" "'
local dataset `" "$na_data" "'
disp `target'
disp `structural'
disp `aspirational'
disp `dataset'

confirmdir "$output\Growth Comparison Analysis"
if _rc != 0 {
                mkdir "$output\Growth Comparison Analysis"
                di "Country folder created"
				}
else {
                di "Country folder already exists"
                }
local fig=0
**********************************************
*Structural differences in levels in most recent year
**********************************************
*Labor productivity in most recent year
use "$data\GrowthEpisodes_short_$target_country.dta", clear
gen gdp_ppp_usd=(gdp_curr_lcu/ppp_cf)
gen pwgdp_ppp_usd_all=gdp_ppp_usd/pop_empl
gen pwgdp_ppp_usd_agr=(gdp_ppp_usd*gdp_share_curr_agr)/pop_empl_agr
gen pwgdp_ppp_usd_ind=(gdp_ppp_usd*gdp_share_curr_ind)/pop_empl_ind
gen pwgdp_ppp_usd_ser=(gdp_ppp_usd*gdp_share_curr_ser)/pop_empl_ser
egen year_max=max(year), by(iso3)
keep if year_max==year
collapse (mean) pwgdp_ppp_usd_all pwgdp_ppp_usd_agr pwgdp_ppp_usd_ind pwgdp_ppp_usd_ser, by(country country_type iso3 year)
reshape long pwgdp_ppp_usd, i(country country_type iso3 year) j(sector) string
rename  pwgdp_ppp_usd pwgdp_ppp
replace sector="aa" if sector=="_all"
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
levelsof year, local(year)
graph hbar pwgdp_ppp, ///
over(sector, relabel(1 "econ.-wide" 2 "agriculture" 3 "industry" 4 "services") label(labsize(small))) over(country_type, relabel(1 "$target_country") label(labsize(medium) angle(90)) gap(*1.5)) ///
ytitle(`"value added per worker in current USD, PPP adjusted (`year')"', size(small)) ///
ylabel(, grid gmax gmin labsize(small)) ///
graphregion(color(white)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
*Sectoral employment shares in most recent year
use "$data\GrowthEpisodes_short_$target_country.dta", clear
egen year_max=max(year), by(iso3)
keep if year_max==year
collapse (mean) empl_share_agr empl_share_ind empl_share_ser, by(country country_type iso3 year)
reshape long empl_share, i(country country_type iso3 year) j(sector) string
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
levelsof year, local(year)
graph hbar empl_share, ///
over(sector, relabel(1 "agriculture" 2 "industry" 3 "services") label(labsize(small))) over(country_type, relabel(1 "$target_country") label(labsize(medium) angle(90)) gap(*1.5)) ///
ytitle(`"share in total employment (`year')"', size(small)) ///
ylabel(, grid gmax gmin labsize(small)) ///
graphregion(color(white)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
*Sectoral value added shares in most recent year
use "$data\GrowthEpisodes_short_$target_country.dta", clear
egen year_max=max(year), by(iso3)
keep if year_max==year
collapse (mean) gdp_share_curr_agr gdp_share_curr_ind gdp_share_curr_ser, by(country country_type iso3 year)
reshape long gdp_share_curr, i(country country_type iso3 year) j(sector) string
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
levelsof year, local(year)
graph hbar gdp_share_curr, ///
over(sector, relabel(1 "agriculture" 2 "industry" 3 "services") label(labsize(small))) over(country_type, relabel(1 "$target_country") label(labsize(medium) angle(90)) gap(*1.5)) ///
ytitle(`"share in total value added (`year')"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
**********************************************
*Growth, per capita and productivity
**********************************************
*Per capita GDP growth
use "$data\GrowthEpisodes_short_$target_country.dta", clear
collapse (mean) gr_pcgdp, by(country country_type episode episode_start episode_end)
replace gr_pcgdp=gr_pcgdp*100
graph hbar gr_pcgdp, ///
over(episode,  label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
ytitle(`"annualized growth in p.c. GDP in %"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
note("Source: Jobs and Structural Change Stata (JSCS) Tool based on $source data", height(6) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
*Growth in labor productivity
use "$data\GrowthEpisodes_short_$target_country.dta", clear
collapse (mean) gr_pwgdp, by(country country_type episode episode_start episode_end)
replace gr_pwgdp=gr_pwgdp*100
graph hbar gr_pwgdp, ///
over(episode,  label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
ytitle(`"annualized growth in value added per worker in %"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
**********************************************
*Decompositions of per capita growth
**********************************************
*Figure: Decompositions of per capita growth over long period by country type (target vs. structural vs aspirational) and by country
use "$data\GrowthEpisodes_long_$target_country.dta", clear
collapse (mean)  grcont_pwgdp grcont_empl grcont_part grcont_wap, by(country country_type episode episode_start episode_end)
rename grcont_pwgdp var1
rename grcont_empl  var2
rename grcont_part  var3
rename grcont_wap   var4
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
replace var4=var4*100
reshape long var, i(country country_type episode) j(type)
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(country,  label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
asyvars stack ytitle(`"annual p.c. GDP growth, in percent (`start'-`end')"', size(small)) ///
graphregion(color(white)) ///
legend(label(1 "av. labor prod.") label(2 "employment") label(3 "labor force part.") label (4 "working age pop.") cols(2) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
*Figure: Decompositions of per capita growth over short periods by country type (target vs. structural vs aspirational)
use "$data\GrowthEpisodes_short_$target_country.dta", clear
levelsof episode_id, local(ep)
foreach e of local ep {
preserve
keep if episode_id==`e'
collapse (mean) gr_pcgdp grcont_pwgdp grcont_empl grcont_part grcont_wap, by(country country_type episode episode_start episode_end)
rename grcont_pwgdp var1
rename grcont_empl  var2
rename grcont_part  var3
rename grcont_wap   var4
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
replace var4=var4*100
reshape long var, i(country country_type episode) j(type)
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(country,  label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
asyvars stack ytitle(`"annual p.c. GDP growth, in percent (`start'-`end')"', size(small)) ///
graphregion(color(white)) ///
legend(label(1 "av. labor prod.") label(2 "employment") label(3 "labor force part.") label (4 "working age pop.") cols(2) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
*graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
**********************************************
*Sectoral contributions to labor productivity
**********************************************
*Figure: Within- and across-sector productivity gains over long period by country
use "$data\GrowthEpisodes_long_$target_country.dta", clear
collapse (mean) gr_pwgdp grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, by(country country_type episode episode_start episode_end)
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i(country country_type episode) j(type)
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(country,  label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
asyvars stack  ytitle(`"annualized growth in value added per worker in % (`start'-`end')"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") label (4 "population") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
*Figure: Within- and across-sector productivity gains over short period2 by country
use "$data\GrowthEpisodes_short_$target_country.dta", clear
levelsof episode_id, local(ep)
foreach e of local ep {
preserve
keep if episode_id==`e'
collapse (mean) gr_pwgdp grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, by(country country_type episode episode_start episode_end)
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i(country country_type episode) j(type)
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(country,  label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
asyvars stack  ytitle(`"annualized growth in value added per worker in % (`start'-`end')"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") label (4 "population") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
*Figure: Within- and across-sector productivity gains over long period by country type (target vs. structural vs aspirational) and by sector
use "$data\GrowthEpisodes_long_$target_country.dta", clear
collapse (mean) grcont_pwgdp_wthn_agr grcont_pwgdp_srloc_agr grcont_pwgdp_drloc_agr grcont_pwgdp_wthn_ind grcont_pwgdp_srloc_ind grcont_pwgdp_drloc_ind grcont_pwgdp_wthn_ser grcont_pwgdp_srloc_ser grcont_pwgdp_drloc_ser, by(country_type country episode episode_start episode_end)
reshape long grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, i(country_type country episode episode_start episode_end) j(sector) string
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i( country_type country episode episode_start episode_end sector) j(type)
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(sector, label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) ///
asyvars stack ytitle(`"annualized growth in value added per worker in % (`start'-`end')"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
*****
*Figure: Within- and across-sector productivity gains over short periods by country type (target vs. structural vs aspirational) and by sector
use "$data\GrowthEpisodes_short_$target_country.dta", clear
levelsof episode_id, local(ep)
foreach e of local ep {
preserve
keep if episode_id==`e'
collapse (mean) grcont_pwgdp_wthn_agr grcont_pwgdp_srloc_agr grcont_pwgdp_drloc_agr grcont_pwgdp_wthn_ind grcont_pwgdp_srloc_ind grcont_pwgdp_drloc_ind grcont_pwgdp_wthn_ser grcont_pwgdp_srloc_ser grcont_pwgdp_drloc_ser, by(country_type country episode episode_start episode_end)
reshape long grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, i(country_type country episode episode_start episode_end) j(sector) string
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i( country_type country episode episode_start episode_end sector) j(type)
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(sector, label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
asyvars stack ytitle(`"annualized growth in value added per worker in % (`start'-`end')"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall))  
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
*Figure: Within- and across-sector productivity gains over long period by country in the agricultural sector
use "$data\GrowthEpisodes_long_$target_country.dta", clear
collapse (mean) grcont_pwgdp_wthn_agr grcont_pwgdp_srloc_agr grcont_pwgdp_drloc_agr grcont_pwgdp_wthn_ind grcont_pwgdp_srloc_ind grcont_pwgdp_drloc_ind grcont_pwgdp_wthn_ser grcont_pwgdp_srloc_ser grcont_pwgdp_drloc_ser, by(country_type country episode episode_start episode_end)
reshape long grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, i(country_type country episode episode_start episode_end) j(sector) string
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i( country_type country episode episode_start episode_end sector) j(type)
keep if sector=="agriculture"
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(country, label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
asyvars stack ytitle(`"Agr. sector contribution to annualized growth in value added per worker (`start'-`end')"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
*Figure: Within- and across-sector productivity gains over long period by country in the industry sector
use "$data\GrowthEpisodes_long_$target_country.dta", clear
collapse (mean) grcont_pwgdp_wthn_agr grcont_pwgdp_srloc_agr grcont_pwgdp_drloc_agr grcont_pwgdp_wthn_ind grcont_pwgdp_srloc_ind grcont_pwgdp_drloc_ind grcont_pwgdp_wthn_ser grcont_pwgdp_srloc_ser grcont_pwgdp_drloc_ser, by(country_type country episode episode_start episode_end)
reshape long grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, i(country_type country episode episode_start episode_end) j(sector) string
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i( country_type country episode episode_start episode_end sector) j(type)
keep if sector=="industry"
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(country, label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
asyvars stack ytitle(`"Ind. contribution to annualized growth in value added per worker (`start'-`end')"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
*Figure: Within- and across-sector productivity gains over long period by country in the services sector
use "$data\GrowthEpisodes_long_$target_country.dta", clear
collapse (mean) grcont_pwgdp_wthn_agr grcont_pwgdp_srloc_agr grcont_pwgdp_drloc_agr grcont_pwgdp_wthn_ind grcont_pwgdp_srloc_ind grcont_pwgdp_drloc_ind grcont_pwgdp_wthn_ser grcont_pwgdp_srloc_ser grcont_pwgdp_drloc_ser, by(country_type country episode episode_start episode_end)
reshape long grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, i(country_type country episode episode_start episode_end) j(sector) string
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i( country_type country episode episode_start episode_end sector) j(type)
keep if sector=="services"
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(country, label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
asyvars stack ytitle(`"Ser. contribution to annualized growth in value added per worker (`start'-`end')"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
*Figure: Within- and across-sector productivity gains over short periods by country in the agricultural sector
use "$data\GrowthEpisodes_short_$target_country.dta", clear
levelsof episode_id, local(ep)
foreach e of local ep {
preserve
keep if episode_id==`e'
collapse (mean) grcont_pwgdp_wthn_agr grcont_pwgdp_srloc_agr grcont_pwgdp_drloc_agr grcont_pwgdp_wthn_ind grcont_pwgdp_srloc_ind grcont_pwgdp_drloc_ind grcont_pwgdp_wthn_ser grcont_pwgdp_srloc_ser grcont_pwgdp_drloc_ser, by(country_type country episode episode_start episode_end)
reshape long grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, i(country_type country episode episode_start episode_end) j(sector) string
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i( country_type country episode episode_start episode_end sector) j(type)
levelsof sector, local(sector)
keep if sector=="agriculture"
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(country,  label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
asyvars stack ytitle(`"Agr. contribution to annualized growth in value added per worker (`start'-`end')"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
*Figure: Within- and across-sector productivity gains over short periods by country in the industry sector
use "$data\GrowthEpisodes_short_$target_country.dta", clear
levelsof episode_id, local(ep)
foreach e of local ep {
preserve
keep if episode_id==`e'
collapse (mean) grcont_pwgdp_wthn_agr grcont_pwgdp_srloc_agr grcont_pwgdp_drloc_agr grcont_pwgdp_wthn_ind grcont_pwgdp_srloc_ind grcont_pwgdp_drloc_ind grcont_pwgdp_wthn_ser grcont_pwgdp_srloc_ser grcont_pwgdp_drloc_ser, by(country_type country episode episode_start episode_end)
reshape long grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, i(country_type country episode episode_start episode_end) j(sector) string
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i( country_type country episode episode_start episode_end sector) j(type)
levelsof sector, local(sector)
keep if sector=="industry"
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(country,  label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
asyvars stack ytitle(`"Ind. contribution to annualized growth in value added per worker (`start'-`end')"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
*Figure: Within- and across-sector productivity gains over short periods by country in the services sector
use "$data\GrowthEpisodes_short_$target_country.dta", clear
levelsof episode_id, local(ep)
foreach e of local ep {
preserve
keep if episode_id==`e'
collapse (mean) grcont_pwgdp_wthn_agr grcont_pwgdp_srloc_agr grcont_pwgdp_drloc_agr grcont_pwgdp_wthn_ind grcont_pwgdp_srloc_ind grcont_pwgdp_drloc_ind grcont_pwgdp_wthn_ser grcont_pwgdp_srloc_ser grcont_pwgdp_drloc_ser, by(country_type country episode episode_start episode_end)
reshape long grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, i(country_type country episode episode_start episode_end) j(sector) string
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i( country_type country episode episode_start episode_end sector) j(type)
levelsof sector, local(sector)
keep if sector=="services"
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(country,  label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
asyvars stack ytitle(`"Ser. contribution to annualized growth in value added per worker (`start'-`end')"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
use "$data\GrowthEpisode_short_global_$target_country.dta", clear
drop if grcont_pwgdp==.
keep if incstat_start=="LIC" | incstat_start=="LMIC" 
drop if grcont_pwgdp_wthn==. | grcont_pwgdp_srloc==.
if "$target_country"!="all" {
preserve
local target `" "$target_country" "'
local structural `" "$structural_comparators" "'
local aspirational `" "$aspirational_comparators" "'
disp `target'
disp `structural'
disp `aspirational'
keep if inlist(iso3,`target', `structural', `aspirational')
gen country_type=1 if inlist(iso3,`target')
replace country_type=2 if inlist(iso3,`structural')
replace country_type=3 if inlist(iso3,`aspirational')
label define crty_types 1 "target" 2 "structural" 3 "aspirational"
label values country_type crty_types
drop if country_type==1
collapse (mean) grcont_pwgdp_wthn grcont_pwgdp_srloc, by(country_type year)
tempfile comparators
save `comparators'
restore
append using `comparators'
}
replace grcont_pwgdp_wthn=grcont_pwgdp_wthn*100
replace grcont_pwgdp_srloc=grcont_pwgdp_srloc*100
su grcont_pwgdp_wthn, detail
local i=r(p50)
local max_wthn=r(max)
local min_wthn=r(min)
disp `i'
su grcont_pwgdp_srloc, detail
local j=r(p50)
disp `j'
local max_srloc=r(max)
local min_srloc=r(min)
levelsof episode_start, local(start)
levelsof episode, local(eps)

graph twoway (scatter grcont_pwgdp_wthn grcont_pwgdp_srloc if country_type==., msize(small) mcolor("0 173 228")) ///
             (scatter grcont_pwgdp_wthn grcont_pwgdp_srloc if country_type==2, msize(medium) msymbol(diamond) mcolor("225 106 45") mlabel(year) mlabcolor("225 106 45")) ///
			 (scatter grcont_pwgdp_wthn grcont_pwgdp_srloc if country_type==3, msize(medium) msymbol(diamond) mcolor("96 125 139") mlabel(year) mlabcolor("96 125 139")) ///
			 (scatter grcont_pwgdp_wthn grcont_pwgdp_srloc if iso3=="$target_country", msize(medium) msymbol(diamond) mcolor("0 35 69") mlabel(year) mlabcolor("0 35 69")) ///
			 , yline(`i') xline(`j') ///
ylabel(, grid gmax gmin labsize(small)) xlabel(, labsize(small)) ///
legend(order(2 "structural (mean)" 3 "aspirational (mean)" 4 "$target_country" ) c(3)) ///
ytitle("Within-sector annualized " "growth in value added per worker (%-points)", size(small)) ///
xtitle("Static across-sector annualized" "growth in value added per worker (%-points)", size(small)) ///
graphregion(color(white)) ///
text(`max_wthn' `min_srloc' "high within" "&" "low across", place(se) size(vsmall) color(gs7)) ///
text(`max_wthn' `max_srloc' "high within" "&" "high across", place(sw) size(vsmall) color(gs7)) ///
text(`min_wthn' `max_srloc' "low within" "&" "high across", place(nw) size(vsmall) color(gs7)) ///
text(`min_wthn' `min_srloc' "low within" "&" "low across", place(ne) size(vsmall) color(gs7)) ///
note("Explanatory note: Only $episodes growth episodes for LIC and LMIC included" "(unless specified in group of structural and aspirational comparators)", height(6)  span size(vsmall)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
**********************************************
*Capital stock and capital deepening
**********************************************
*Growth of capital stock
use "$data\GrowthEpisodes_allyears_$target_country.dta", clear
su year if caps_pwt_rnna!=.
local year_max1=r(max)
disp `year_max1'
su year
local year_max2=r(max)
if `year_max1'<`year_max2' {
drop if year>`year_max1'
local years "$years"
disp `years'
keep if inlist(year, `years', `year_max1')
sort iso3 year
}
drop episode*
sort iso3 year
bysort iso3: gen episode_length=year[_n]-year[_n-1]
bysort iso3: gen episode_start=year[_n-1]
bysort iso3: gen episode_end=year[_n] if episode_start!=.
egen episode=concat(episode_start episode_end) if episode_start!=., punct(-) 
sort iso3 year
bysort iso3: gen caps_index=100 if _n==1
bysort iso3: replace caps_index=caps_index[_n-1]*(caps_pwt_rnna[_n]/caps_pwt_rnna[_n-1]) if _n>1
by iso3: gen gr_cs=(caps_pwt_rnna[_n]/caps_pwt_rnna[_n-1])^(1/episode_length)-1
collapse (mean) gr_cs, by(country_type country episode episode_start episode_end)
replace gr_cs=gr_cs*100
graph hbar gr_cs, ///
over(episode,  label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
ytitle(`"annualized change in capital stock in %"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace
*Capital Deepening
use "$data\GrowthEpisodes_allyears_$target_country.dta", clear
su year if caps_pwt_rnna!=.
local year_max1=r(max)
disp `year_max1'
su year
local year_max2=r(max)
if `year_max1'<`year_max2' {
drop if year>`year_max1'
local years "$years"
disp `years'
keep if inlist(year, `years', `year_max1')
sort iso3 year
}
drop episode*
sort iso3 year
bysort iso3: gen episode_length=year[_n]-year[_n-1]
bysort iso3: gen episode_start=year[_n-1]
bysort iso3: gen episode_end=year[_n] if episode_start!=.
egen episode=concat(episode_start episode_end) if episode_start!=., punct(-) 
gen cl_ratio=caps_pwt_rnna/pop_empl
sort iso3 year
by iso3: gen gr_cl_ratio=(cl_ratio[_n]/cl_ratio[_n-1])^(1/episode_length)-1
collapse (mean) gr_cl_ratio, by(country_type country episode episode_start episode_end)
replace gr_cl_ratio=gr_cl_ratio*100
graph hbar gr_cl_ratio, ///
over(episode,  label(labsize(small))) over(country_type, relabel(1 "$target_country")  label(labsize(medium) angle(90)) gap(*1.5)) nofill ///
ytitle(`"capital deepening in %"', size(small)) ///
graphregion(color(white)) ///
ylabel(, grid gmax gmin labsize(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1 
graph export "$output\Growth Comparison Analysis\ComparisonAnalysis_fig`fig'.png", as(png) name("Graph") replace

clear
set graphics on
graph close
}

disp _newline(100)  
dis as result "All figures for the Growth Episodes Country Comparison Analysis were prepared successfully."
disp _newline(1)  
dis as result "To continue you have the following options:"
disp _newline(1)
dis as result "Option 1:"
dis as text  "Global benchmarking analysis of structural features of "`target'"'s economy. In the STATA Command Window below, please type:" 
disp as result "JSCS_benchmarking"
disp as text "and press enter."
disp _newline(1)
dis as result "Option 2:"
dis as text  "Growth episodes analysis for "`target'". In the STATA Command Window below, please type:"
disp as result "JSCS_episodes"
disp as text "and press enter."
disp _newline(1)
dis as result "Option 3:"
dis as text  "Growth episodes analysis for "`target'" versus structural and aspirational peers. In the STATA Command Window below, please type: "
disp as result "JSCS_comparisons"
disp as text "and press enter."
end

/*
**********************************************
*Jobs in comparison
**********************************************
use "$data\GrowthEpisodes_long_$target_country.dta", clear
sort iso3 year
by iso3: gen d_wempl=empl_share_wge[_n]-empl_share_wge[_n-1]
by iso3: gen gr_wempl=wempl_pop[_n]/wempl_pop[_n-1]-1
by iso3: gen d_lfp=lfp_rate[_n]-lfp_rate[_n-1]
gen wagepop_share=wempl_pop/pop_wap
by iso3: gen d_wagepop=wagepop_share[_n]-wagepop_share[_n-1]
by iso3: gen share_wage=(wempl_pop[_n]-wempl_pop[_n-1])/(pop_wap[_n]-pop_wap[_n-1])

graph hbar  share_wage, over(country,  label(labsize(small)) sort(d_wempl)) over(country_type,  label(labsize(medium) angle(90)) gap(*1.5)) nofill
graph hbar  d_wagepop, over(country,  label(labsize(small)) sort(d_wempl)) over(country_type,  label(labsize(medium) angle(90)) gap(*1.5)) nofill
graph hbar  d_wempl, over(country,  label(labsize(small)) sort(d_wempl)) over(country_type,  label(labsize(medium) angle(90)) gap(*1.5)) nofill
graph hbar  gr_wempl, over(country,  label(labsize(small)) sort(d_wempl)) over(country_type,  label(labsize(medium) angle(90)) gap(*1.5)) nofill
graph hbar  d_lfp, over(country,  label(labsize(small)) sort(d_wempl)) over(country_type,  label(labsize(medium) angle(90)) gap(*1.5)) nofill

use "$data\GrowthEpisodes_$target_country.dta", clear
sort iso3 year
by iso3: gen d_wempl=empl_share_wge[_n]-empl_share_wge[_n-1]
by iso3: gen gr_wempl=wempl_pop[_n]/wempl_pop[_n-1]-1
by iso3: gen d_lfp=lfp_rate[_n]-lfp_rate[_n-1]
gen wagepop_share=wempl_pop/pop
by iso3: gen d_wagepop=wagepop_share[_n]-wagepop_share[_n-1]
gen struct_change=grcont_pwgdp_srloc_ind+grcont_pwgdp_srloc_ser
graph twoway (scatter struct_change d_wempl) (scatter struct_change d_wempl if iso3=="$target_country") (qfit struct_change d_wempl)



