program JSCS_episodes
disp _newline(100)  
dis as text "The figures for the Growth Episodes Analysis are being prepared. Please wait. "

quietly {
set graphics off
local years "$years"
disp `years'
local target `" "$target_country" "'
local structural `" "$structural_comparators" "'
local aspirational `" "$aspirational_comparators" "'
local dataset `" "$na_data" "'
disp `target'
disp `structural'
disp `aspirational'
disp `dataset'

confirmdir "$output\Growth Episodes Analysis"
if _rc != 0 {
                mkdir "$output\Growth Episodes Analysis"
                di "Country folder created"
				}
else {
                di "Country folder already exists"
                }
local fig=0
*Productivity growth index
preserve
use "$data\GrowthEpisodes_allyears_$target_country.dta", clear
keep if iso3=="$target_country" 
bysort iso3: gen pwgdp_index=100 if _n==1
bysort iso3: replace pwgdp_index=pwgdp_index[_n-1]*(1+gr_pwgdp[_n])^(year[_n]-year[_n-1]) if _n>1
local years "$years"
local x_min=min(`years')
local x_max=max(`years')
su pwgdp_index if iso3=="$target_country"
local y_min=round((r(min)-20),10)
local y_max=round((r(max)+20),10)
local int=round((`y_max'-`y_min')/10,10)
levelsof country, local(countries)
graph twoway (line pwgdp_index year), ytick(`y_min'(`int')`y_max') ylabel(`y_min'(`int')`y_max', grid gmax gmin labsize(small)) xtick(`x_min'(1)`x_max') xlabel(`x_min'(1)`x_max', labsize(small) angle(45)) ///
xtitle("") ytitle(`"value added per worker, index (`x_min'=100)"', size(small)) ///
graphregion(color(white)) ///
legend(on label(1 "$target_country") size(small)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
*Figure: GDP growth decomposition, by expenditure
{
preserve
use "$data\GrowthEpisodes_short_$target_country.dta", clear
keep if iso3=="$target_country"
collapse (mean) grcont_gdp_cpriv grcont_gdp_cgovt grcont_gdp_itotl grcont_gdp_exprt grcont_gdp_imprt, by(episode)
rename grcont_gdp_cpriv var1
rename grcont_gdp_cgovt var2
rename grcont_gdp_itotl var3
rename grcont_gdp_exprt var4
rename grcont_gdp_imprt var5
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
replace var4=var4*100
replace var5=var5*100
reshape long var, i(episode) j(type)
graph bar var, ///
over(type) over(episode, label(labsize(small) angle(45))) ///
asyvars stack ytitle("annual GDP growth, in percent", size(small)) ///
legend(label(1 "priv. cons.") label(2 "gov. cons.") label(3 "investment") label(4 "exports") label (5 "imports") cols(2) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
*Figure: GDP gexpenditure accounts
{
preserve
use "$data\GrowthEpisodes_short_$target_country.dta", clear
keep if iso3=="$target_country"
levels year, local(yrs)
disp "`yrs'"
gen trade_bal=100*(exprt_share_curr-imprt_share_curr)
replace cpriv_share_curr=cpriv_share_curr*100
replace cgovt_share_curr=cgovt_share_curr*100
replace itotl_share_curr=itotl_share_curr*100
graph twoway (line cpriv_share_curr year), ///
xtick("`yrs'") xlabel("`yrs'", angle(45) labsize(small)) ylabel(, grid gmax gmin labsize(small)) ///
xtitle("") ytitle("private consumption, percent of GDP", height(6) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace

graph twoway (line cgovt_share_curr year) , ///
xtick("`yrs'") xlabel("`yrs'", angle(45) labsize(small)) ylabel(, grid gmax gmin labsize(small)) ///
xtitle("") ytitle("public spending, percent of GDP", height(6) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace

graph twoway  (line itotl_share_curr year), ///
xtick("`yrs'") xlabel("`yrs'", angle(45) labsize(small)) ylabel(, grid gmax gmin labsize(small)) ///
xtitle("") ytitle("investment, percent of GDP", height(6) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace

graph twoway (line trade_bal year), ///
legend(label(1 "trade balance") size(small)) ///
xtick("`yrs'") xlabel("`yrs'", angle(45) labsize(small)) ylabel(, grid gmax gmin labsize(small)) ///
xtitle("") ytitle("trade balance, percent of GDP", height(6) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore 
}

*Figure: pc GDP growth decompositions over short periods
{
preserve
use "$data\GrowthEpisodes_short_$target_country.dta", clear
keep if iso3=="$target_country"
collapse (mean) grcont_pwgdp grcont_empl grcont_part grcont_wap, by(episode)
rename grcont_pwgdp var1
rename grcont_empl  var2
rename grcont_part  var3
rename grcont_wap   var4
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
replace var4=var4*100
reshape long var, i(episode) j(type)
graph hbar var, ///
over(type) over(episode,  label(labsize(small))) ///
asyvars stack ytitle("annual p.c. GDP growth, in percent", size(small)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "av. labor prod.") label(2 "employment") label(3 "labor force part.") label (4 "working age pop.") cols(2) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
*Figure: Employment across main sectors
{
preserve
use "$data\GrowthEpisodes_short_$target_country.dta", clear
keep if iso3=="$target_country"
keep country year pop_empl_agr pop_empl_ind pop_empl_ser
reshape long pop_empl_, i(year) j(sector) string
replace pop_empl_=pop_empl_/1000
levels year, local(yrs)
disp "`yrs'"
graph bar pop_empl_,  over(year) over(sector, relabel(1"agriculture" 2 "industry" 3 "services")) asyvar ///
legend(cols(3) size(small)) /// 
ytitle("employment, 1000 of workers", height(6) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
*Figure: Employment shares across main sectors
{
preserve
use "$data\GrowthEpisodes_short_$target_country.dta", clear
keep if iso3=="$target_country"
keep country year empl_share_agr empl_share_ind empl_share_ser
reshape long empl_share_, i(year) j(sector) string
replace empl_share_=empl_share_*100
levels year, local(yrs)
disp "`yrs'"
graph bar empl_share_, over(sector) over(year) stack asyvar ///
legend(label(1 "agriculture") label(2 "industry") label(3 "services") cols(3) size(small)) ///
blabel(bar, position(center) size(vsmall) color(white) format(%3.1f)) ///
ytitle("share in total emplyment, in percent", height(6) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
*Figure: Value added shares across main sectors
{
preserve
use "$data\GrowthEpisodes_short_$target_country.dta", clear
keep if iso3=="$target_country"
keep country year gdp_share_curr_agr gdp_share_curr_ind gdp_share_curr_ser
reshape long gdp_share_curr_, i(year) j(sector) string
replace gdp_share_curr_=gdp_share_curr_*100
levels year, local(yrs)
disp "`yrs'"
graph bar gdp_share_curr_, over(sector) over(year) stack asyvar ///
legend(label(1 "agriculture") label(2 "industry") label(3 "services") cols(3) size(small)) ///
blabel(bar, position(center) size(vsmall) color(white) format(%3.1f)) ///
ytitle("share in total value added, in percent", height(6) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
*Figure: Labor productivity across sectors
{
preserve
use "$data\GrowthEpisodes_short_$target_country.dta", clear
keep if iso3=="$target_country"
sort iso3 year
keep country year pwgdp_cons pwgdp_agr pwgdp_ind pwgdp_ser 
reshape long pwgdp_, i(year) j(sector) string
replace pwgdp_=pwgdp_/1000
replace sector="aa" if sector=="cons"
graph bar pwgdp_, over(year) over(sector, relabel(1 "econ.-wide" 2 "agriculture" 3 "industry" 4 "services"))  asyvar ///
legend(cols(3) size(small)) /// 
ytitle("value added per worker in thousand of LCU," "in 2010 constant prices", height(6) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
*Figure: Within- and across-sector productivity gains over short periods
{
preserve
use "$data\GrowthEpisodes_short_$target_country.dta", clear
keep if iso3=="$target_country"
collapse (mean) grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, by(episode)
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i(episode) j(type)
graph hbar var, ///
over(type) over(episode, label(labsize(small)))  ///
asyvars stack ytitle("growth in value added per worker, in %", size(small)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") label (4 "population") cols(3) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
*Figure: Within- and across-sector productivity gains over short periods by sector
{
preserve
use "$data\GrowthEpisodes_short_$target_country.dta", clear
keep if iso3=="$target_country"
collapse (mean) grcont_pwgdp_wthn_agr grcont_pwgdp_srloc_agr grcont_pwgdp_drloc_agr grcont_pwgdp_wthn_ind grcont_pwgdp_srloc_ind grcont_pwgdp_drloc_ind grcont_pwgdp_wthn_ser grcont_pwgdp_srloc_ser grcont_pwgdp_drloc_ser, by(episode episode_id)
reshape long grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, i(episode) j(sector) string
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i(episode sector) j(type)
graph hbar var, ///
over(type) over(episode, sort(episode_id) label(labsize(small))) over(sector, label(labsize(medium) angle(90)))  ///
asyvars stack ytitle("annualized growth in value added per worker in %", size(small)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
{
*Figure: Within- and across-sector productivity gains over long period by sector
preserve
use "$data\GrowthEpisodes_long_$target_country.dta", clear
keep if iso3=="$target_country"
collapse (mean) grcont_pwgdp_wthn_agr grcont_pwgdp_srloc_agr grcont_pwgdp_drloc_agr grcont_pwgdp_wthn_ind grcont_pwgdp_srloc_ind grcont_pwgdp_drloc_ind grcont_pwgdp_wthn_ser grcont_pwgdp_srloc_ser grcont_pwgdp_drloc_ser, by(episode episode_start episode_end)
reshape long grcont_pwgdp_wthn grcont_pwgdp_srloc grcont_pwgdp_drloc, i(episode episode_start episode_end) j(sector) string
replace sector="agriculture" if sector=="_agr"
replace sector="industry" if sector=="_ind"
replace sector="services" if sector=="_ser"
rename grcont_pwgdp_wthn var1
rename grcont_pwgdp_srloc  var2
rename grcont_pwgdp_drloc  var3
replace var1=var1*100
replace var2=var2*100
replace var3=var3*100
reshape long var, i(episode episode_start episode_end sector) j(type)
levelsof episode_start, local(start)
levelsof episode_end, local(end)
graph hbar var, ///
over(type) over(sector, label(labsize(small)))  ///
asyvars stack ytitle(`"annualized growth in value added per worker in % (`start'-`end')"', size(small)) ///
ylabel(, grid gmax gmin labsize(small)) ///
legend(label(1 "within-sector") label(2 "across-sector") label(3 "dynamic") cols(3) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore
}
*Capital stock and capital deepening
preserve
use "$data\GrowthEpisodes_allyears_$target_country.dta", clear
keep if iso3=="$target_country"
gen cl_ratio=caps_pwt_rnna/pop_empl
bysort iso3: gen cl_index=100 if _n==1
bysort iso3: replace cl_index=cl_index[_n-1]*(cl_ratio[_n]/cl_ratio[_n-1]) if _n>1
bysort iso3: gen capstock_index=100 if _n==1
bysort iso3: replace capstock_index=capstock_index[_n-1]*(caps_pwt_rnna[_n]/caps_pwt_rnna[_n-1]) if _n>1
bysort iso3: gen empl_index=100 if _n==1
bysort iso3: replace empl_index=empl_index[_n-1]*(pop_empl[_n]/pop_empl[_n-1]) if _n>1

local years "$years"
local x_min=min(`years')
local x_max=max(`years')
graph twoway (line capstock_index year if iso3=="$target_country") (line empl_index year if iso3=="$target_country") (line cl_index year if iso3=="$target_country"), ///
ylabel(, grid gmax gmin labsize(small)) xtick(`x_min'(1)`x_max') xlabel(`x_min'(1)`x_max', labsize(small) angle(45)) ///
xtitle("") ytitle(`"index $target_country, `x_min'=100 (constant prices)"', height (6) size(small))  ///
legend(on label(1 "capital stock in (cons. prices)") label(2 "working pop.") label (3 "capital-labor ratio") c(3) span size(small))  ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
restore

*Figure: Wage employment over time
use "$data\GrowthEpisodes_short_$target_country.dta", clear
keep if iso3=="$target_country"
sort iso3 year
levels year, local(yrs)
disp "`yrs'"
replace empl_share_wge=empl_share_wge*100
graph twoway (line empl_share_wge year), ///
xtick("`yrs'") xlabel("`yrs'", angle(45) labsize(small)) ylabel(, grid gmax gmin labsize(small)) ///
xtitle("") ytitle("wage employment, in % of total employment", height(6) size(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
*Figure: Changes in wage employment over short periods
use "$data\GrowthEpisodes_short_$target_country.dta", clear
keep if iso3=="$target_country"
sort iso3 year
by iso3: gen d_wempl=(empl_share_wge[_n]-empl_share_wge[_n-1])/episode_length
collapse (mean) d_wempl, by(episode episode_start episode_end)
replace d_wempl=d_wempl*100
graph hbar d_wempl, over(episode, sort(episode_id) label(labsize(small))) ///
ytitle("average annual %-point change in wage employment", size(small)) ///
ylabel(, grid gmax gmin labsize(small)) ///
graphregion(color(white)) ///
caption("World Bank Jobs Group - Jobs and Structural Change Stata (JSCS) Tool", height(4) span size(vsmall)) 
local fig=`fig'+1
graph export "$output\Growth Episodes Analysis\EpisodesAnalysis_fig`fig'.png", as(png) name("Graph") replace
clear
set graphics on
graph close
}
disp _newline(100)  
dis as result "All figures for the Growth Episodes Analysis were prepared successfully."
disp _newline(1)  
dis as result "To continue you have the following options:"
disp _newline(1)
dis as result "Option 1:"
dis as text  "Global benchmarking analysis of structural features of "`target'"'s economy. In the STATA Command Window below, please type:" 
disp as result "JSCS_benchmarking"
disp as text "and press enter."
disp _newline(1)
dis as result "Option 2:"
dis as text  "Growth episodes analysis for "`target'". In the STATA Command Window below, please type:"
disp as result "JSCS_episodes"
disp as text "and press enter."
disp _newline(1)
dis as result "Option 3:"
dis as text  "Growth episodes analysis for "`target'" versus structural and aspirational peers. In the STATA Command Window below, please type: "
disp as result "JSCS_comparisons"
disp as text "and press enter."
end


