program JSCS_prep

*--------------------------------*--------------------------------*---------------------------------------
*-----THIS PROGRAM CREATES TABS and GRAPHS for the analaysis of Jobs and Structural Change using WDI data

* Authors: Andreas Eberhard-Ruiz, Dino Merotto
* For any questions, please contact: aeberhard@worldbank.org or dmerotto@worldbank.org

*------------------------------*--------------------------------*----------------------------------------
disp _newline(100)  
dis as text "Folder structure and data are being prepared."

quietly {
ssc install confirmdir, replace
ssc install grstyle, replace
ssc install palettes, replace
ssc install colrspace, replace
set more off

local years "$years"
disp `years'
local target `" "$target_country" "'
local structural `" "$structural_comparators" "'
local aspirational `" "$aspirational_comparators" "'
local dataset `" "$na_data" "'
disp `target'
disp `structural'
disp `aspirational'
disp `dataset'

*Defining folder structure within user defined directory:

local date : dis %td_CCYYNNDD date(c(current_date), "DMY")


forvalues i=1/100 {
confirmdir "$directory\Outputs\JSCS_`date'_`i'"
if _rc != 0 {
                mkdir "$directory\Outputs\JSCS_`date'_`i'"
                di "JSCS Main folder created"
				mkdir "$directory\Outputs\JSCS_`date'_`i'\Data"
				di "JSCS Data sub-folder created"
				mkdir "$directory\Outputs\JSCS_`date'_`i'\Output"
				di "JSCS Output sub-folder created"
				global analysis "$directory\Outputs\JSCS_`date'_`i'"
				global data "$directory\Outputs\JSCS_`date'_`i'\Data"
				global output "$directory\Outputs\JSCS_`date'_`i'\Output"
				continue, break
				}
}

*Defining the source of data (WDI vs GRO)

if strpos("$na_data", "GRO") {
use "$directory\Ancilliary Data\GRO_JSCS_dataset.dta", clear
gen byte country_type	 = 0
foreach include of local target {
       replace country_type = 1 if iso3 == "`include'"
}
su country_type
if r(max)==0 {
disp _newline(10)
di as err "no data in $na_data dataset is available for $target_country" 
di as err "review selection"
exit
}
keep if country_type==1
drop country_type

gen byte wanted_years = 0
local y=0
foreach ok of local years {
local y=`y'+1
       replace wanted = 1 if year == `ok'
}

su wanted_years
if r(sum)<`y' {
disp _newline(10)
di as err "not all selected years in $na_data dataset are available for $target_country"
di as err "review selection"
exit
}
drop wanted_years

merge 1:1 iso3 yea using "$directory\Ancilliary Data\WDI_JSCS_dataset.dta", keepusing(pop_wap pop_uempl pop_share_1564 pop_share_abv64 er_lcuperusd)
keep if _merge==3
drop _merge
gen adjustvar=(pop_share_1564 + pop_share_abv64)/pop_share_1564

local varlist pop_empl_agr pop_empl pop_empl_ind pop_empl_ser 
foreach var of varlist `varlist' {
replace `var'=`var'*1000 
}

local varlist gdp_curr_lcu gdp_cons_lcu va_agr_curr va_agr_cons va_ind_curr va_ind_cons va_ser_curr va_ser_cons
foreach var of varlist `varlist' {
replace `var'=`var'*1000000 
}

replace pop_empl=pop_empl/adjustvar
replace pop_empl_agr=pop_empl_agr/adjustvar
replace pop_empl_ind=pop_empl_ind/adjustvar
replace pop_empl_ser=pop_empl_ser/adjustvar

gen pop_active=(pop_empl+pop_uempl)
gen lfp_rate=(pop_empl+pop_uempl)/pop_wap
gen empl_rate=pop_empl/(pop_empl+pop_uempl)
gen ueml_rate=pop_uempl/(pop_empl+pop_uempl)


gen gdp_curr_usd= gdp_curr_lcu/er_lcuperusd
gen help1=gdp_cons_lcu if year==2010
egen base=min(help1), by(iso3)
gen defl=gdp_cons_lcu/base
gen help2=gdp_curr_usd if year==2010
egen gdp_usd_base=min(help2), by(iso3)
gen gdp_cons_usd=gdp_usd_base/defl
drop help1 base defl help2 gdp_usd_base
tempfile gro_data
save `gro_data'
use "$directory\Ancilliary Data\WDI_JSCS_dataset.dta", clear

local varlist gdp_curr_lcu gdp_cons_lcu gdp_curr_usd gdp_cons_usd gdp_share_curr_agr gdp_share_curr_ind gdp_share_curr_ser gdp_share_cons_agr gdp_share_cons_ind gdp_share_cons_ser va_agr_curr va_ind_curr va_ser_curr va_agr_cons va_ind_cons va_ser_cons gdp_deflator_lcu pop pop_ma pop_fe pop_wap pop_wap_ma pop_wap_fe pop_active pop_active_ma pop_active_fe pop_empl pop_empl_ma pop_empl_fe pop_empl_agr pop_empl_ind pop_empl_ser pop_empl empl_share_agr empl_share_ind empl_share_ser

foreach var of varlist `varlist' {
replace `var'=. if iso3=="`target'" 
}

merge 1:1 iso3 year using `gro_data', update replace
drop _merge
global source Groningen ETD
save "$directory\Ancilliary Data\use_dataset.dta", replace
}

if strpos("$na_data", "WDI") {
use "$directory\Ancilliary Data\WDI_JSCS_dataset.dta", clear
save "$directory\Ancilliary Data\use_dataset.dta", replace
global source World Bank WDI
}

*Step1
****************************
*Growth Episodes Dataset
****************************
use "$directory\Ancilliary Data\use_dataset.dta", clear
if "$target_country"!="all" {
gen byte country_type	 = 0
foreach include of local target {
       replace country_type = 1 if iso3 == "`include'"
}

foreach include of local structural {
       replace country_type = 2 if iso3 == "`include'"
}

foreach include of local aspirational {
       replace country_type = 3 if iso3 == "`include'"
}
keep if country_type==1 | country_type==2 | country_type==3
label define crty_types 1 "target" 2 "structural" 3 "aspirational"
label values country_type crty_types

}
if "`years'"!="all" {
gen byte wanted_years = 0
foreach ok of local years {
       replace wanted = 1 if year == `ok'
}
sort iso3 year
by iso3: gen help1=sum(wanted)
egen gfcf_ttl_cons_lcu=total(itotl_cons_lcu), by(help1)
egen gfcf_ttl_curr_lcu=total(itotl_curr_lcu), by(help1)
drop help1
keep if wanted_years==1
sort iso3 year
by iso3: replace gfcf_ttl_cons=. if _n==1
drop wanted_years
sort iso3 year
}

bysort iso3: gen episode_length=year[_n]-year[_n-1]

gen pcgdp_cons=gdp_cons_lcu/pop
gen pcgdp_curr=gdp_curr_lcu/pop
gen pcgdp_cons_usd=gdp_cons_usd/pop
gen pcgdp_curr_usd=gdp_curr_usd/pop
gen pwgdp_cons=gdp_cons_lcu/pop_empl
gen pwgdp_curr=gdp_curr_lcu/pop_empl
sort iso3 year
by iso3: gen gr_gdp=(gdp_cons_lcu/gdp_cons_lcu[_n-1])^(1/episode_length)-1
by iso3: gen gr_pcgdp=(pcgdp_cons/pcgdp_cons[_n-1])^(1/episode_length)-1
by iso3: gen gr_pcgdp_usd=(pcgdp_cons_usd/pcgdp_cons_usd[_n-1])^(1/episode_length)-1
by iso3: gen gr_pwgdp=(pwgdp_cons/pwgdp_cons[_n-1])^(1/episode_length)-1
by iso3: gen gr_pop=(pop/pop[_n-1])^(1/episode_length)-1
by iso3: gen gr_empl_rate=(empl_rate/empl_rate[_n-1])^(1/episode_length)-1
by iso3: gen gr_lfp_rate=(lfp_rate/lfp_rate[_n-1])^(1/episode_length)-1
by iso3: gen gr_wap_rate=(wap_rate/wap_rate[_n-1])^(1/episode_length)-1
tempvar w
gen `w'= gr_pwgdp+1
tempvar e
gen `e'= gr_empl_rate+1
tempvar p
gen `p'= gr_lfp_rate+1
tempvar a 
gen `a'= gr_wap_rate+1
gen grcont_pwgdp=	(1/4)	 * 	 ((`w')*(`e')*(`p')*(`a') - ( 1 )*(`e')*(`p')*(`a')) + ///
					(1/4)	 *	 ((`w')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`w')*(`e')*(`p')*( 1 ) - ( 1 )*(`e')*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`w')*(`e')*( 1 )*(`a') - ( 1 )*(`e')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`w')*( 1 )*(`p')*(`a') - ( 1 )*( 1 )*(`p')*(`a')) + ///
					(1/12)	 *	 ((`w')*(`e')*( 1 )*( 1 ) - ( 1 )*(`e')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`w')*( 1 )*(`p')*( 1 ) - ( 1 )*( 1 )*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`w')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))
gen grcont_pwgdp_share=grcont_pwgdp/gr_pcgdp			
gen grcont_empl=	(1/4)	 * 	 ((`e')*(`w')*(`p')*(`a') - ( 1 )*(`w')*(`p')*(`a')) + ///
					(1/4)	 *	 ((`e')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`e')*(`w')*(`p')*( 1 ) - ( 1 )*(`w')*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`e')*(`w')*( 1 )*(`a') - ( 1 )*(`w')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`e')*( 1 )*(`p')*(`a') - ( 1 )*( 1 )*(`p')*(`a')) + ///
					(1/12)	 *	 ((`e')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`e')*( 1 )*(`p')*( 1 ) - ( 1 )*( 1 )*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`e')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))					
gen grcont_empl_share=grcont_empl/gr_pcgdp
gen grcont_part=	(1/4)	 * 	 ((`p')*(`w')*(`e')*(`a') - ( 1 )*(`w')*(`e')*(`a')) + ///
					(1/4)	 *	 ((`p')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`p')*(`w')*(`e')*( 1 ) - ( 1 )*(`w')*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`p')*(`w')*( 1 )*(`a') - ( 1 )*(`w')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`p')*( 1 )*(`e')*(`a') - ( 1 )*( 1 )*(`e')*(`a')) + ///
					(1/12)	 *	 ((`p')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`p')*( 1 )*(`e')*( 1 ) - ( 1 )*( 1 )*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`p')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))
gen grcont_part_share=grcont_part/gr_pcgdp
gen grcont_wap=		(1/4)	 * 	 ((`a')*(`w')*(`e')*(`p') - ( 1 )*(`w')*(`e')*(`p')) + ///
					(1/4)	 *	 ((`a')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`a')*(`w')*(`e')*( 1 ) - ( 1 )*(`w')*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`a')*(`w')*( 1 )*(`p') - ( 1 )*(`w')*( 1 )*(`p')) + ///
					(1/12)	 *	 ((`a')*( 1 )*(`e')*(`p') - ( 1 )*( 1 )*(`e')*(`p')) + ///
					(1/12)	 *	 ((`a')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`a')*( 1 )*(`e')*( 1 ) - ( 1 )*( 1 )*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`a')*( 1 )*( 1 )*(`p') - ( 1 )*( 1 )*( 1 )*(`p'))		
gen grcont_wap_share=grcont_wap/gr_pcgdp

local sect agr ind ser
foreach s of local sect {
gen pwgdp_curr_`s'=(va_`s'_curr/pop_empl_`s')
gen pwgdp_`s'=(va_`s'_cons/pop_empl_`s')
sort iso3 year
by iso3: gen gr_pwgdp_`s'=(pwgdp_`s'[_n]/pwgdp_`s'[_n-1])^(1/episode_length)-1
by iso3: gen grcont_pwgdp_wthn_`s'_share=((pwgdp_`s'[_n]-pwgdp_`s'[_n-1])*empl_share_`s'[_n-1])/(pwgdp_cons[_n]-pwgdp_cons[_n-1])
by iso3: gen grcont_pwgdp_srloc_`s'_share=((empl_share_`s'[_n]-empl_share_`s'[_n-1])*pwgdp_`s'[_n-1])/(pwgdp_cons[_n]-pwgdp_cons[_n-1])
by iso3: gen grcont_pwgdp_drloc_`s'_share=((empl_share_`s'[_n]-empl_share_`s'[_n-1])*(pwgdp_`s'[_n]-pwgdp_`s'[_n-1]))/(pwgdp_cons[_n]-pwgdp_cons[_n-1])

gen grcont_pwgdp_`s'_share=grcont_pwgdp_wthn_`s'_share+grcont_pwgdp_srloc_`s'_share+grcont_pwgdp_drloc_`s'_share
gen grcont_pwgdp_wthn_`s'=grcont_pwgdp_wthn_`s'_share*gr_pwgdp
gen grcont_pwgdp_srloc_`s'=grcont_pwgdp_srloc_`s'_share*gr_pwgdp
gen grcont_pwgdp_drloc_`s'=grcont_pwgdp_drloc_`s'_share*gr_pwgdp
gen grcont_pwgdp_`s'=grcont_pwgdp_`s'_share*gr_pwgdp
}
gen grcont_pwgdp_wthn_share= grcont_pwgdp_wthn_agr_share+grcont_pwgdp_wthn_ind_share+grcont_pwgdp_wthn_ser_share
gen grcont_pwgdp_srloc_share=grcont_pwgdp_srloc_agr_share+grcont_pwgdp_srloc_ind_share+grcont_pwgdp_srloc_ser_share
gen grcont_pwgdp_drloc_share=grcont_pwgdp_drloc_agr_share+grcont_pwgdp_drloc_ind_share+grcont_pwgdp_drloc_ser_share
gen grcont_pwgdp_wthn=grcont_pwgdp_wthn_agr+grcont_pwgdp_wthn_ind+grcont_pwgdp_wthn_ser
gen grcont_pwgdp_srloc=grcont_pwgdp_srloc_agr+grcont_pwgdp_srloc_ind+grcont_pwgdp_srloc_ser
gen grcont_pwgdp_drloc=grcont_pwgdp_drloc_agr+grcont_pwgdp_drloc_ind+grcont_pwgdp_drloc_ser

gen gdp_cons_lcu_adj=cpriv_cons_lcu+cgovt_cons_lcu+itotl_cons_lcu+exprt_cons_lcu-imprt_cons_lcu
gen grcont_gdp_cpriv=(cpriv_cons_lcu[_n]-cpriv_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_cgovt=(cgovt_cons_lcu[_n]-cgovt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_itotl=(itotl_cons_lcu[_n]-itotl_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_exprt=(exprt_cons_lcu[_n]-exprt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_imprt=(-imprt_cons_lcu[_n]+imprt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp

gen prodratio= ((va_ind_cons+va_ser_cons)/(pop_empl_ind+pop_empl_ser))/(va_agr_cons/pop_empl_agr)
gen wempl_pop=pop_empl*empl_share_wge
gen slfempl_pop=pop_empl*empl_share_slf
gen wtonw_ratio=wempl_pop/slfempl_pop

*additional variables
sort iso3 year
bysort iso3: gen pcgdp_index=100 if _n==1
bysort iso3: replace pcgdp_index=pcgdp_index[_n-1]*(1+gr_pcgdp[_n])^(episode_length) if _n>1
bysort iso3: gen er_index=1 if _n==1
bysort iso3: replace er_index=er_index[_n-1]*((er_lcuperusd[_n]/er_lcuperusd[_n-1])^(episode_length)) if _n>1
replace er_index=1/er_index
replace er_index=100*er_index
bysort iso3: replace er_reer=100 if _n==1
bysort iso3: replace er_reer=er_reer[_n-1]*((er_reer[_n]/er_reer[_n-1])^(episode_length)) if _n>1

bysort iso3: gen episode_start=year[_n-1]
bysort iso3: gen episode_end=year[_n] if episode_start!=.
egen episode=concat(episode_start episode_end) if episode_start!=., punct(-) 
bysort iso3: gen incstat_start=inc_class_hist[_n-1]
levelsof episode, clean local(episodes) 
global episodes `episodes'
disp "$episodes"

bysort iso3: gen episode_id=_n-1
replace episode_id=. if episode_id==0
drop `w' `e' `p' `a'
save "$data\GrowthEpisodes_short_$target_country.dta", replace

****************
use "$directory\Ancilliary Data\use_dataset.dta", clear
if "$target_country"!="all" {
gen byte country_type	 = 0
foreach include of local target {
       replace country_type = 1 if iso3 == "`include'"
}

foreach include of local structural {
       replace country_type = 2 if iso3 == "`include'"
}

foreach include of local aspirational {
       replace country_type = 3 if iso3 == "`include'"
}
keep if country_type==1 | country_type==2 | country_type==3
label define crty_types 1 "target" 2 "structural" 3 "aspirational"
label values country_type crty_types

}
if "`years'"!="all" {
gen byte wanted_years = 0
foreach ok of local years {
       replace wanted = 1 if year == `ok'
}
sort iso3 year
by iso3: gen help1=sum(wanted)
egen gfcf_ttl_cons_lcu=total(itotl_cons_lcu), by(help1)
egen gfcf_ttl_curr_lcu=total(itotl_curr_lcu), by(help1)
drop help1
keep if wanted_years==1
drop wanted_years
sort iso3 year
}


egen year_min=min(year)
egen year_max=max(year)
keep if year==year_min | year==year_max

bysort iso3: gen episode_length=year[_n]-year[_n-1]

gen pcgdp_cons=gdp_cons_lcu/pop
gen pcgdp_curr=gdp_curr_lcu/pop
gen pcgdp_cons_usd=gdp_cons_usd/pop
gen pcgdp_curr_usd=gdp_curr_usd/pop
gen pwgdp_cons=gdp_cons_lcu/pop_empl
gen pwgdp_curr=gdp_curr_lcu/pop_empl
sort iso3 year
by iso3: gen gr_gdp=(gdp_cons_lcu/gdp_cons_lcu[_n-1])^(1/episode_length)-1
by iso3: gen gr_pcgdp=(pcgdp_cons/pcgdp_cons[_n-1])^(1/episode_length)-1
by iso3: gen gr_pcgdp_usd=(pcgdp_cons_usd/pcgdp_cons_usd[_n-1])^(1/episode_length)-1
by iso3: gen gr_pwgdp=(pwgdp_cons/pwgdp_cons[_n-1])^(1/episode_length)-1
by iso3: gen gr_pop=(pop/pop[_n-1])^(1/episode_length)-1
by iso3: gen gr_empl_rate=(empl_rate/empl_rate[_n-1])^(1/episode_length)-1
by iso3: gen gr_lfp_rate=(lfp_rate/lfp_rate[_n-1])^(1/episode_length)-1
by iso3: gen gr_wap_rate=(wap_rate/wap_rate[_n-1])^(1/episode_length)-1
tempvar w
gen `w'= gr_pwgdp+1
tempvar e
gen `e'= gr_empl_rate+1
tempvar p
gen `p'= gr_lfp_rate+1
tempvar a 
gen `a'= gr_wap_rate+1
gen grcont_pwgdp=	(1/4)	 * 	 ((`w')*(`e')*(`p')*(`a') - ( 1 )*(`e')*(`p')*(`a')) + ///
					(1/4)	 *	 ((`w')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`w')*(`e')*(`p')*( 1 ) - ( 1 )*(`e')*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`w')*(`e')*( 1 )*(`a') - ( 1 )*(`e')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`w')*( 1 )*(`p')*(`a') - ( 1 )*( 1 )*(`p')*(`a')) + ///
					(1/12)	 *	 ((`w')*(`e')*( 1 )*( 1 ) - ( 1 )*(`e')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`w')*( 1 )*(`p')*( 1 ) - ( 1 )*( 1 )*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`w')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))
gen grcont_pwgdp_share=grcont_pwgdp/gr_pcgdp			
gen grcont_empl=	(1/4)	 * 	 ((`e')*(`w')*(`p')*(`a') - ( 1 )*(`w')*(`p')*(`a')) + ///
					(1/4)	 *	 ((`e')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`e')*(`w')*(`p')*( 1 ) - ( 1 )*(`w')*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`e')*(`w')*( 1 )*(`a') - ( 1 )*(`w')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`e')*( 1 )*(`p')*(`a') - ( 1 )*( 1 )*(`p')*(`a')) + ///
					(1/12)	 *	 ((`e')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`e')*( 1 )*(`p')*( 1 ) - ( 1 )*( 1 )*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`e')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))					
gen grcont_empl_share=grcont_empl/gr_pcgdp
gen grcont_part=	(1/4)	 * 	 ((`p')*(`w')*(`e')*(`a') - ( 1 )*(`w')*(`e')*(`a')) + ///
					(1/4)	 *	 ((`p')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`p')*(`w')*(`e')*( 1 ) - ( 1 )*(`w')*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`p')*(`w')*( 1 )*(`a') - ( 1 )*(`w')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`p')*( 1 )*(`e')*(`a') - ( 1 )*( 1 )*(`e')*(`a')) + ///
					(1/12)	 *	 ((`p')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`p')*( 1 )*(`e')*( 1 ) - ( 1 )*( 1 )*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`p')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))
gen grcont_part_share=grcont_part/gr_pcgdp
gen grcont_wap=		(1/4)	 * 	 ((`a')*(`w')*(`e')*(`p') - ( 1 )*(`w')*(`e')*(`p')) + ///
					(1/4)	 *	 ((`a')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`a')*(`w')*(`e')*( 1 ) - ( 1 )*(`w')*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`a')*(`w')*( 1 )*(`p') - ( 1 )*(`w')*( 1 )*(`p')) + ///
					(1/12)	 *	 ((`a')*( 1 )*(`e')*(`p') - ( 1 )*( 1 )*(`e')*(`p')) + ///
					(1/12)	 *	 ((`a')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`a')*( 1 )*(`e')*( 1 ) - ( 1 )*( 1 )*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`a')*( 1 )*( 1 )*(`p') - ( 1 )*( 1 )*( 1 )*(`p'))		
gen grcont_wap_share=grcont_wap/gr_pcgdp

local sect agr ind ser
foreach s of local sect {
gen pwgdp_curr_`s'=(va_`s'_curr/pop_empl_`s')
gen pwgdp_`s'=(va_`s'_cons/pop_empl_`s')
sort iso3 year
by iso3: gen gr_pwgdp_`s'=(pwgdp_`s'[_n]/pwgdp_`s'[_n-1])^(1/episode_length)-1
by iso3: gen grcont_pwgdp_wthn_`s'_share=((pwgdp_`s'[_n]-pwgdp_`s'[_n-1])*empl_share_`s'[_n-1])/(pwgdp_cons[_n]-pwgdp_cons[_n-1])
by iso3: gen grcont_pwgdp_srloc_`s'_share=((empl_share_`s'[_n]-empl_share_`s'[_n-1])*pwgdp_`s'[_n-1])/(pwgdp_cons[_n]-pwgdp_cons[_n-1])
by iso3: gen grcont_pwgdp_drloc_`s'_share=((empl_share_`s'[_n]-empl_share_`s'[_n-1])*(pwgdp_`s'[_n]-pwgdp_`s'[_n-1]))/(pwgdp_cons[_n]-pwgdp_cons[_n-1])

gen grcont_pwgdp_`s'_share=grcont_pwgdp_wthn_`s'_share+grcont_pwgdp_srloc_`s'_share+grcont_pwgdp_drloc_`s'_share
gen grcont_pwgdp_wthn_`s'=grcont_pwgdp_wthn_`s'_share*gr_pwgdp
gen grcont_pwgdp_srloc_`s'=grcont_pwgdp_srloc_`s'_share*gr_pwgdp
gen grcont_pwgdp_drloc_`s'=grcont_pwgdp_drloc_`s'_share*gr_pwgdp
gen grcont_pwgdp_`s'=grcont_pwgdp_`s'_share*gr_pwgdp
}
gen grcont_pwgdp_wthn_share= grcont_pwgdp_wthn_agr_share+grcont_pwgdp_wthn_ind_share+grcont_pwgdp_wthn_ser_share
gen grcont_pwgdp_srloc_share=grcont_pwgdp_srloc_agr_share+grcont_pwgdp_srloc_ind_share+grcont_pwgdp_srloc_ser_share
gen grcont_pwgdp_drloc_share=grcont_pwgdp_drloc_agr_share+grcont_pwgdp_drloc_ind_share+grcont_pwgdp_drloc_ser_share
gen grcont_pwgdp_wthn=grcont_pwgdp_wthn_agr+grcont_pwgdp_wthn_ind+grcont_pwgdp_wthn_ser
gen grcont_pwgdp_srloc=grcont_pwgdp_srloc_agr+grcont_pwgdp_srloc_ind+grcont_pwgdp_srloc_ser
gen grcont_pwgdp_drloc=grcont_pwgdp_drloc_agr+grcont_pwgdp_drloc_ind+grcont_pwgdp_drloc_ser

gen gdp_cons_lcu_adj=cpriv_cons_lcu+cgovt_cons_lcu+itotl_cons_lcu+exprt_cons_lcu-imprt_cons_lcu
gen grcont_gdp_cpriv=(cpriv_cons_lcu[_n]-cpriv_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_cgovt=(cgovt_cons_lcu[_n]-cgovt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_itotl=(itotl_cons_lcu[_n]-itotl_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_exprt=(exprt_cons_lcu[_n]-exprt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_imprt=(-imprt_cons_lcu[_n]+imprt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp

gen prodratio= ((va_ind_cons+va_ser_cons)/(pop_empl_ind+pop_empl_ser))/(va_agr_cons/pop_empl_agr)
gen wempl_pop=pop_empl*empl_share_wge
gen slfempl_pop=pop_empl*empl_share_slf
gen wtonw_ratio=wempl_pop/slfempl_pop

*additional variables
sort iso3 year
bysort iso3: gen pcgdp_index=100 if _n==1
bysort iso3: replace pcgdp_index=pcgdp_index[_n-1]*(1+gr_pcgdp[_n])^(episode_length) if _n>1
bysort iso3: gen er_index=1 if _n==1
bysort iso3: replace er_index=er_index[_n-1]*((er_lcuperusd[_n]/er_lcuperusd[_n-1])^(episode_length)) if _n>1
replace er_index=1/er_index
replace er_index=100*er_index
bysort iso3: replace er_reer=100 if _n==1
bysort iso3: replace er_reer=er_reer[_n-1]*((er_reer[_n]/er_reer[_n-1])^(episode_length)) if _n>1

bysort iso3: gen episode_start=year[_n-1]
bysort iso3: gen episode_end=year[_n] if episode_start!=.
egen episode=concat(episode_start episode_end) if episode_start!=., punct(-) 
bysort iso3: gen incstat_start=inc_class_hist[_n-1]

drop year_min year_max
drop `w' `e' `p' `a'
save "$data\GrowthEpisodes_long_$target_country.dta", replace
******
use "$directory\Ancilliary Data\use_dataset.dta", clear
if "$target_country"!="all" {
gen byte country_type	 = 0
foreach include of local target {
       replace country_type = 1 if iso3 == "`include'"
}

foreach include of local structural {
       replace country_type = 2 if iso3 == "`include'"
}

foreach include of local aspirational {
       replace country_type = 3 if iso3 == "`include'"
}
keep if country_type==1 | country_type==2 | country_type==3
label define crty_types 1 "target" 2 "structural" 3 "aspirational"
label values country_type crty_types

}
if "`years'"!="all" {
gen byte wanted_years = 0
foreach ok of local years {
       replace wanted = 1 if year == `ok'
}
sort iso3 year
by iso3: gen help1=sum(wanted)
egen gfcf_ttl_cons_lcu=total(itotl_cons_lcu), by(help1)
egen gfcf_ttl_curr_lcu=total(itotl_curr_lcu), by(help1)
drop help1
keep if wanted_years==1
drop wanted_years
sort iso3 year
}

bysort iso3: gen episode_length=year[_n]-year[_n-1]

gen pcgdp_cons=gdp_cons_lcu/pop
gen pcgdp_curr=gdp_curr_lcu/pop
gen pcgdp_cons_usd=gdp_cons_usd/pop
gen pcgdp_curr_usd=gdp_curr_usd/pop
gen pwgdp_cons=gdp_cons_lcu/pop_empl
gen pwgdp_curr=gdp_curr_lcu/pop_empl
sort iso3 year
by iso3: gen gr_gdp=(gdp_cons_lcu/gdp_cons_lcu[_n-1])^(1/episode_length)-1
by iso3: gen gr_pcgdp=(pcgdp_cons/pcgdp_cons[_n-1])^(1/episode_length)-1
by iso3: gen gr_pcgdp_usd=(pcgdp_cons_usd/pcgdp_cons_usd[_n-1])^(1/episode_length)-1
by iso3: gen gr_pwgdp=(pwgdp_cons/pwgdp_cons[_n-1])^(1/episode_length)-1
by iso3: gen gr_pop=(pop/pop[_n-1])^(1/episode_length)-1
by iso3: gen gr_empl_rate=(empl_rate/empl_rate[_n-1])^(1/episode_length)-1
by iso3: gen gr_lfp_rate=(lfp_rate/lfp_rate[_n-1])^(1/episode_length)-1
by iso3: gen gr_wap_rate=(wap_rate/wap_rate[_n-1])^(1/episode_length)-1
tempvar w
gen `w'= gr_pwgdp+1
tempvar e
gen `e'= gr_empl_rate+1
tempvar p
gen `p'= gr_lfp_rate+1
tempvar a 
gen `a'= gr_wap_rate+1
gen grcont_pwgdp=	(1/4)	 * 	 ((`w')*(`e')*(`p')*(`a') - ( 1 )*(`e')*(`p')*(`a')) + ///
					(1/4)	 *	 ((`w')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`w')*(`e')*(`p')*( 1 ) - ( 1 )*(`e')*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`w')*(`e')*( 1 )*(`a') - ( 1 )*(`e')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`w')*( 1 )*(`p')*(`a') - ( 1 )*( 1 )*(`p')*(`a')) + ///
					(1/12)	 *	 ((`w')*(`e')*( 1 )*( 1 ) - ( 1 )*(`e')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`w')*( 1 )*(`p')*( 1 ) - ( 1 )*( 1 )*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`w')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))
gen grcont_pwgdp_share=grcont_pwgdp/gr_pcgdp			
gen grcont_empl=	(1/4)	 * 	 ((`e')*(`w')*(`p')*(`a') - ( 1 )*(`w')*(`p')*(`a')) + ///
					(1/4)	 *	 ((`e')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`e')*(`w')*(`p')*( 1 ) - ( 1 )*(`w')*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`e')*(`w')*( 1 )*(`a') - ( 1 )*(`w')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`e')*( 1 )*(`p')*(`a') - ( 1 )*( 1 )*(`p')*(`a')) + ///
					(1/12)	 *	 ((`e')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`e')*( 1 )*(`p')*( 1 ) - ( 1 )*( 1 )*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`e')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))					
gen grcont_empl_share=grcont_empl/gr_pcgdp
gen grcont_part=	(1/4)	 * 	 ((`p')*(`w')*(`e')*(`a') - ( 1 )*(`w')*(`e')*(`a')) + ///
					(1/4)	 *	 ((`p')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`p')*(`w')*(`e')*( 1 ) - ( 1 )*(`w')*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`p')*(`w')*( 1 )*(`a') - ( 1 )*(`w')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`p')*( 1 )*(`e')*(`a') - ( 1 )*( 1 )*(`e')*(`a')) + ///
					(1/12)	 *	 ((`p')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`p')*( 1 )*(`e')*( 1 ) - ( 1 )*( 1 )*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`p')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))
gen grcont_part_share=grcont_part/gr_pcgdp
gen grcont_wap=		(1/4)	 * 	 ((`a')*(`w')*(`e')*(`p') - ( 1 )*(`w')*(`e')*(`p')) + ///
					(1/4)	 *	 ((`a')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`a')*(`w')*(`e')*( 1 ) - ( 1 )*(`w')*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`a')*(`w')*( 1 )*(`p') - ( 1 )*(`w')*( 1 )*(`p')) + ///
					(1/12)	 *	 ((`a')*( 1 )*(`e')*(`p') - ( 1 )*( 1 )*(`e')*(`p')) + ///
					(1/12)	 *	 ((`a')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`a')*( 1 )*(`e')*( 1 ) - ( 1 )*( 1 )*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`a')*( 1 )*( 1 )*(`p') - ( 1 )*( 1 )*( 1 )*(`p'))		
gen grcont_wap_share=grcont_wap/gr_pcgdp

local sect agr ind ser
foreach s of local sect {
gen pwgdp_curr_`s'=(va_`s'_curr/pop_empl_`s')
gen pwgdp_`s'=(va_`s'_cons/pop_empl_`s')
sort iso3 year
by iso3: gen gr_pwgdp_`s'=(pwgdp_`s'[_n]/pwgdp_`s'[_n-1])^(1/episode_length)-1
by iso3: gen grcont_pwgdp_wthn_`s'_share=((pwgdp_`s'[_n]-pwgdp_`s'[_n-1])*empl_share_`s'[_n-1])/(pwgdp_cons[_n]-pwgdp_cons[_n-1])
by iso3: gen grcont_pwgdp_srloc_`s'_share=((empl_share_`s'[_n]-empl_share_`s'[_n-1])*pwgdp_`s'[_n-1])/(pwgdp_cons[_n]-pwgdp_cons[_n-1])
by iso3: gen grcont_pwgdp_drloc_`s'_share=((empl_share_`s'[_n]-empl_share_`s'[_n-1])*(pwgdp_`s'[_n]-pwgdp_`s'[_n-1]))/(pwgdp_cons[_n]-pwgdp_cons[_n-1])

gen grcont_pwgdp_`s'_share=grcont_pwgdp_wthn_`s'_share+grcont_pwgdp_srloc_`s'_share+grcont_pwgdp_drloc_`s'_share
gen grcont_pwgdp_wthn_`s'=grcont_pwgdp_wthn_`s'_share*gr_pwgdp
gen grcont_pwgdp_srloc_`s'=grcont_pwgdp_srloc_`s'_share*gr_pwgdp
gen grcont_pwgdp_drloc_`s'=grcont_pwgdp_drloc_`s'_share*gr_pwgdp
gen grcont_pwgdp_`s'=grcont_pwgdp_`s'_share*gr_pwgdp
}
gen grcont_pwgdp_wthn_share= grcont_pwgdp_wthn_agr_share+grcont_pwgdp_wthn_ind_share+grcont_pwgdp_wthn_ser_share
gen grcont_pwgdp_srloc_share=grcont_pwgdp_srloc_agr_share+grcont_pwgdp_srloc_ind_share+grcont_pwgdp_srloc_ser_share
gen grcont_pwgdp_drloc_share=grcont_pwgdp_drloc_agr_share+grcont_pwgdp_drloc_ind_share+grcont_pwgdp_drloc_ser_share
gen grcont_pwgdp_wthn=grcont_pwgdp_wthn_agr+grcont_pwgdp_wthn_ind+grcont_pwgdp_wthn_ser
gen grcont_pwgdp_srloc=grcont_pwgdp_srloc_agr+grcont_pwgdp_srloc_ind+grcont_pwgdp_srloc_ser
gen grcont_pwgdp_drloc=grcont_pwgdp_drloc_agr+grcont_pwgdp_drloc_ind+grcont_pwgdp_drloc_ser

gen gdp_cons_lcu_adj=cpriv_cons_lcu+cgovt_cons_lcu+itotl_cons_lcu+exprt_cons_lcu-imprt_cons_lcu
gen grcont_gdp_cpriv=(cpriv_cons_lcu[_n]-cpriv_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_cgovt=(cgovt_cons_lcu[_n]-cgovt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_itotl=(itotl_cons_lcu[_n]-itotl_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_exprt=(exprt_cons_lcu[_n]-exprt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_imprt=(-imprt_cons_lcu[_n]+imprt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp

gen prodratio= ((va_ind_cons+va_ser_cons)/(pop_empl_ind+pop_empl_ser))/(va_agr_cons/pop_empl_agr)
gen wempl_pop=pop_empl*empl_share_wge
gen slfempl_pop=pop_empl*empl_share_slf
gen wtonw_ratio=wempl_pop/slfempl_pop

*additional variables
sort iso3 year
bysort iso3: gen pcgdp_index=100 if _n==1
bysort iso3: replace pcgdp_index=pcgdp_index[_n-1]*(1+gr_pcgdp[_n])^(episode_length) if _n>1
bysort iso3: gen er_index=1 if _n==1
bysort iso3: replace er_index=er_index[_n-1]*((er_lcuperusd[_n]/er_lcuperusd[_n-1])^(episode_length)) if _n>1
replace er_index=1/er_index
replace er_index=100*er_index
bysort iso3: replace er_reer=100 if _n==1
bysort iso3: replace er_reer=er_reer[_n-1]*((er_reer[_n]/er_reer[_n-1])^(episode_length)) if _n>1

bysort iso3: gen episode_start=year[_n-1]
bysort iso3: gen episode_end=year[_n] if episode_start!=.
egen episode=concat(episode_start episode_end) if episode_start!=., punct(-) 
bysort iso3: gen incstat_start=inc_class_hist[_n-1]

drop `w' `e' `p' `a'
save "$data\GrowthEpisodes_allyears_$target_country.dta", replace
*************************
use "$directory\Ancilliary Data\use_dataset.dta", clear
if "`years'"!="all" {
gen byte wanted_years = 0
foreach ok of local years {
       replace wanted = 1 if year == `ok'
}
sort iso3 year
by iso3: gen help1=sum(wanted)
egen gfcf_ttl_cons_lcu=total(itotl_cons_lcu), by(help1)
egen gfcf_ttl_curr_lcu=total(itotl_curr_lcu), by(help1)
drop help1
keep if wanted_years==1
drop wanted_years
sort iso3 year
}

egen year_min=min(year)
egen year_max=max(year)
keep if year==year_min | year==year_max

bysort iso3: gen episode_length=year[_n]-year[_n-1]

gen pcgdp_cons=gdp_cons_lcu/pop
gen pcgdp_curr=gdp_curr_lcu/pop
gen pcgdp_cons_usd=gdp_cons_usd/pop
gen pcgdp_curr_usd=gdp_curr_usd/pop
gen pwgdp_cons=gdp_cons_lcu/pop_empl
gen pwgdp_curr=gdp_curr_lcu/pop_empl
sort iso3 year
by iso3: gen gr_gdp=(gdp_cons_lcu/gdp_cons_lcu[_n-1])^(1/episode_length)-1
by iso3: gen gr_pcgdp=(pcgdp_cons/pcgdp_cons[_n-1])^(1/episode_length)-1
by iso3: gen gr_pcgdp_usd=(pcgdp_cons_usd/pcgdp_cons_usd[_n-1])^(1/episode_length)-1
by iso3: gen gr_pwgdp=(pwgdp_cons/pwgdp_cons[_n-1])^(1/episode_length)-1
by iso3: gen gr_pop=(pop/pop[_n-1])^(1/episode_length)-1
by iso3: gen gr_empl_rate=(empl_rate/empl_rate[_n-1])^(1/episode_length)-1
by iso3: gen gr_lfp_rate=(lfp_rate/lfp_rate[_n-1])^(1/episode_length)-1
by iso3: gen gr_wap_rate=(wap_rate/wap_rate[_n-1])^(1/episode_length)-1
tempvar w
gen `w'= gr_pwgdp+1
tempvar e
gen `e'= gr_empl_rate+1
tempvar p
gen `p'= gr_lfp_rate+1
tempvar a 
gen `a'= gr_wap_rate+1
gen grcont_pwgdp=	(1/4)	 * 	 ((`w')*(`e')*(`p')*(`a') - ( 1 )*(`e')*(`p')*(`a')) + ///
					(1/4)	 *	 ((`w')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`w')*(`e')*(`p')*( 1 ) - ( 1 )*(`e')*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`w')*(`e')*( 1 )*(`a') - ( 1 )*(`e')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`w')*( 1 )*(`p')*(`a') - ( 1 )*( 1 )*(`p')*(`a')) + ///
					(1/12)	 *	 ((`w')*(`e')*( 1 )*( 1 ) - ( 1 )*(`e')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`w')*( 1 )*(`p')*( 1 ) - ( 1 )*( 1 )*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`w')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))
gen grcont_pwgdp_share=grcont_pwgdp/gr_pcgdp			
gen grcont_empl=	(1/4)	 * 	 ((`e')*(`w')*(`p')*(`a') - ( 1 )*(`w')*(`p')*(`a')) + ///
					(1/4)	 *	 ((`e')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`e')*(`w')*(`p')*( 1 ) - ( 1 )*(`w')*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`e')*(`w')*( 1 )*(`a') - ( 1 )*(`w')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`e')*( 1 )*(`p')*(`a') - ( 1 )*( 1 )*(`p')*(`a')) + ///
					(1/12)	 *	 ((`e')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`e')*( 1 )*(`p')*( 1 ) - ( 1 )*( 1 )*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`e')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))					
gen grcont_empl_share=grcont_empl/gr_pcgdp
gen grcont_part=	(1/4)	 * 	 ((`p')*(`w')*(`e')*(`a') - ( 1 )*(`w')*(`e')*(`a')) + ///
					(1/4)	 *	 ((`p')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`p')*(`w')*(`e')*( 1 ) - ( 1 )*(`w')*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`p')*(`w')*( 1 )*(`a') - ( 1 )*(`w')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`p')*( 1 )*(`e')*(`a') - ( 1 )*( 1 )*(`e')*(`a')) + ///
					(1/12)	 *	 ((`p')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`p')*( 1 )*(`e')*( 1 ) - ( 1 )*( 1 )*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`p')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))
gen grcont_part_share=grcont_part/gr_pcgdp
gen grcont_wap=		(1/4)	 * 	 ((`a')*(`w')*(`e')*(`p') - ( 1 )*(`w')*(`e')*(`p')) + ///
					(1/4)	 *	 ((`a')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`a')*(`w')*(`e')*( 1 ) - ( 1 )*(`w')*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`a')*(`w')*( 1 )*(`p') - ( 1 )*(`w')*( 1 )*(`p')) + ///
					(1/12)	 *	 ((`a')*( 1 )*(`e')*(`p') - ( 1 )*( 1 )*(`e')*(`p')) + ///
					(1/12)	 *	 ((`a')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`a')*( 1 )*(`e')*( 1 ) - ( 1 )*( 1 )*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`a')*( 1 )*( 1 )*(`p') - ( 1 )*( 1 )*( 1 )*(`p'))		
gen grcont_wap_share=grcont_wap/gr_pcgdp

local sect agr ind ser
foreach s of local sect {
gen pwgdp_curr_`s'=(va_`s'_curr/pop_empl_`s')
gen pwgdp_`s'=(va_`s'_cons/pop_empl_`s')
sort iso3 year
by iso3: gen gr_pwgdp_`s'=(pwgdp_`s'[_n]/pwgdp_`s'[_n-1])^(1/episode_length)-1
by iso3: gen grcont_pwgdp_wthn_`s'_share=((pwgdp_`s'[_n]-pwgdp_`s'[_n-1])*empl_share_`s'[_n-1])/(pwgdp_cons[_n]-pwgdp_cons[_n-1])
by iso3: gen grcont_pwgdp_srloc_`s'_share=((empl_share_`s'[_n]-empl_share_`s'[_n-1])*pwgdp_`s'[_n-1])/(pwgdp_cons[_n]-pwgdp_cons[_n-1])
by iso3: gen grcont_pwgdp_drloc_`s'_share=((empl_share_`s'[_n]-empl_share_`s'[_n-1])*(pwgdp_`s'[_n]-pwgdp_`s'[_n-1]))/(pwgdp_cons[_n]-pwgdp_cons[_n-1])

gen grcont_pwgdp_`s'_share=grcont_pwgdp_wthn_`s'_share+grcont_pwgdp_srloc_`s'_share+grcont_pwgdp_drloc_`s'_share
gen grcont_pwgdp_wthn_`s'=grcont_pwgdp_wthn_`s'_share*gr_pwgdp
gen grcont_pwgdp_srloc_`s'=grcont_pwgdp_srloc_`s'_share*gr_pwgdp
gen grcont_pwgdp_drloc_`s'=grcont_pwgdp_drloc_`s'_share*gr_pwgdp
gen grcont_pwgdp_`s'=grcont_pwgdp_`s'_share*gr_pwgdp
}
gen grcont_pwgdp_wthn_share= grcont_pwgdp_wthn_agr_share+grcont_pwgdp_wthn_ind_share+grcont_pwgdp_wthn_ser_share
gen grcont_pwgdp_srloc_share=grcont_pwgdp_srloc_agr_share+grcont_pwgdp_srloc_ind_share+grcont_pwgdp_srloc_ser_share
gen grcont_pwgdp_drloc_share=grcont_pwgdp_drloc_agr_share+grcont_pwgdp_drloc_ind_share+grcont_pwgdp_drloc_ser_share
gen grcont_pwgdp_wthn=grcont_pwgdp_wthn_agr+grcont_pwgdp_wthn_ind+grcont_pwgdp_wthn_ser
gen grcont_pwgdp_srloc=grcont_pwgdp_srloc_agr+grcont_pwgdp_srloc_ind+grcont_pwgdp_srloc_ser
gen grcont_pwgdp_drloc=grcont_pwgdp_drloc_agr+grcont_pwgdp_drloc_ind+grcont_pwgdp_drloc_ser

gen gdp_cons_lcu_adj=cpriv_cons_lcu+cgovt_cons_lcu+itotl_cons_lcu+exprt_cons_lcu-imprt_cons_lcu
gen grcont_gdp_cpriv=(cpriv_cons_lcu[_n]-cpriv_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_cgovt=(cgovt_cons_lcu[_n]-cgovt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_itotl=(itotl_cons_lcu[_n]-itotl_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_exprt=(exprt_cons_lcu[_n]-exprt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_imprt=(-imprt_cons_lcu[_n]+imprt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp

gen prodratio= ((va_ind_cons+va_ser_cons)/(pop_empl_ind+pop_empl_ser))/(va_agr_cons/pop_empl_agr)
gen wempl_pop=pop_empl*empl_share_wge
gen slfempl_pop=pop_empl*empl_share_slf
gen wtonw_ratio=wempl_pop/slfempl_pop

*additional variables
sort iso3 year
bysort iso3: gen pcgdp_index=100 if _n==1
bysort iso3: replace pcgdp_index=pcgdp_index[_n-1]*(1+gr_pcgdp[_n])^(episode_length) if _n>1
bysort iso3: gen er_index=1 if _n==1
bysort iso3: replace er_index=er_index[_n-1]*((er_lcuperusd[_n]/er_lcuperusd[_n-1])^(episode_length)) if _n>1
replace er_index=1/er_index
replace er_index=100*er_index
bysort iso3: replace er_reer=100 if _n==1
bysort iso3: replace er_reer=er_reer[_n-1]*((er_reer[_n]/er_reer[_n-1])^(episode_length)) if _n>1

bysort iso3: gen episode_start=year[_n-1]
bysort iso3: gen episode_end=year[_n] if episode_start!=.
egen episode=concat(episode_start episode_end) if episode_start!=., punct(-) 
bysort iso3: gen incstat_start=inc_class_hist[_n-1]
drop year_min year_max
drop `w' `e' `p' `a'
save "$data\GrowthEpisode_long_global_$target_country.dta", replace
*************************
use "$directory\Ancilliary Data\use_dataset.dta", clear
if "`years'"!="all" {
gen byte wanted_years = 0
foreach ok of local years {
       replace wanted = 1 if year == `ok'
}
sort iso3 year
by iso3: gen help1=sum(wanted)
egen gfcf_ttl_cons_lcu=total(itotl_cons_lcu), by(help1)
egen gfcf_ttl_curr_lcu=total(itotl_curr_lcu), by(help1)
drop help1
keep if wanted_years==1
drop wanted_years
sort iso3 year
}


bysort iso3: gen episode_length=year[_n]-year[_n-1]

gen pcgdp_cons=gdp_cons_lcu/pop
gen pcgdp_curr=gdp_curr_lcu/pop
gen pcgdp_cons_usd=gdp_cons_usd/pop
gen pcgdp_curr_usd=gdp_curr_usd/pop
gen pwgdp_cons=gdp_cons_lcu/pop_empl
gen pwgdp_curr=gdp_curr_lcu/pop_empl
sort iso3 year
by iso3: gen gr_gdp=(gdp_cons_lcu/gdp_cons_lcu[_n-1])^(1/episode_length)-1
by iso3: gen gr_pcgdp=(pcgdp_cons/pcgdp_cons[_n-1])^(1/episode_length)-1
by iso3: gen gr_pcgdp_usd=(pcgdp_cons_usd/pcgdp_cons_usd[_n-1])^(1/episode_length)-1
by iso3: gen gr_pwgdp=(pwgdp_cons/pwgdp_cons[_n-1])^(1/episode_length)-1
by iso3: gen gr_pop=(pop/pop[_n-1])^(1/episode_length)-1
by iso3: gen gr_empl_rate=(empl_rate/empl_rate[_n-1])^(1/episode_length)-1
by iso3: gen gr_lfp_rate=(lfp_rate/lfp_rate[_n-1])^(1/episode_length)-1
by iso3: gen gr_wap_rate=(wap_rate/wap_rate[_n-1])^(1/episode_length)-1
tempvar w
gen `w'= gr_pwgdp+1
tempvar e
gen `e'= gr_empl_rate+1
tempvar p
gen `p'= gr_lfp_rate+1
tempvar a 
gen `a'= gr_wap_rate+1
gen grcont_pwgdp=	(1/4)	 * 	 ((`w')*(`e')*(`p')*(`a') - ( 1 )*(`e')*(`p')*(`a')) + ///
					(1/4)	 *	 ((`w')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`w')*(`e')*(`p')*( 1 ) - ( 1 )*(`e')*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`w')*(`e')*( 1 )*(`a') - ( 1 )*(`e')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`w')*( 1 )*(`p')*(`a') - ( 1 )*( 1 )*(`p')*(`a')) + ///
					(1/12)	 *	 ((`w')*(`e')*( 1 )*( 1 ) - ( 1 )*(`e')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`w')*( 1 )*(`p')*( 1 ) - ( 1 )*( 1 )*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`w')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))
gen grcont_pwgdp_share=grcont_pwgdp/gr_pcgdp			
gen grcont_empl=	(1/4)	 * 	 ((`e')*(`w')*(`p')*(`a') - ( 1 )*(`w')*(`p')*(`a')) + ///
					(1/4)	 *	 ((`e')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`e')*(`w')*(`p')*( 1 ) - ( 1 )*(`w')*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`e')*(`w')*( 1 )*(`a') - ( 1 )*(`w')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`e')*( 1 )*(`p')*(`a') - ( 1 )*( 1 )*(`p')*(`a')) + ///
					(1/12)	 *	 ((`e')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`e')*( 1 )*(`p')*( 1 ) - ( 1 )*( 1 )*(`p')*( 1 )) + ///
					(1/12)	 *	 ((`e')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))					
gen grcont_empl_share=grcont_empl/gr_pcgdp
gen grcont_part=	(1/4)	 * 	 ((`p')*(`w')*(`e')*(`a') - ( 1 )*(`w')*(`e')*(`a')) + ///
					(1/4)	 *	 ((`p')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`p')*(`w')*(`e')*( 1 ) - ( 1 )*(`w')*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`p')*(`w')*( 1 )*(`a') - ( 1 )*(`w')*( 1 )*(`a')) + ///
					(1/12)	 *	 ((`p')*( 1 )*(`e')*(`a') - ( 1 )*( 1 )*(`e')*(`a')) + ///
					(1/12)	 *	 ((`p')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`p')*( 1 )*(`e')*( 1 ) - ( 1 )*( 1 )*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`p')*( 1 )*( 1 )*(`a') - ( 1 )*( 1 )*( 1 )*(`a'))
gen grcont_part_share=grcont_part/gr_pcgdp
gen grcont_wap=		(1/4)	 * 	 ((`a')*(`w')*(`e')*(`p') - ( 1 )*(`w')*(`e')*(`p')) + ///
					(1/4)	 *	 ((`a')*( 1 )*( 1 )*( 1 ) - ( 1 )*( 1 )*( 1 )*( 1 )) + ///
					(1/12)	 *	 ((`a')*(`w')*(`e')*( 1 ) - ( 1 )*(`w')*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`a')*(`w')*( 1 )*(`p') - ( 1 )*(`w')*( 1 )*(`p')) + ///
					(1/12)	 *	 ((`a')*( 1 )*(`e')*(`p') - ( 1 )*( 1 )*(`e')*(`p')) + ///
					(1/12)	 *	 ((`a')*(`w')*( 1 )*( 1 ) - ( 1 )*(`w')*( 1 )*( 1 )) + ///			 
					(1/12)	 *	 ((`a')*( 1 )*(`e')*( 1 ) - ( 1 )*( 1 )*(`e')*( 1 )) + ///
					(1/12)	 *	 ((`a')*( 1 )*( 1 )*(`p') - ( 1 )*( 1 )*( 1 )*(`p'))		
gen grcont_wap_share=grcont_wap/gr_pcgdp

local sect agr ind ser
foreach s of local sect {
gen pwgdp_curr_`s'=(va_`s'_curr/pop_empl_`s')
gen pwgdp_`s'=(va_`s'_cons/pop_empl_`s')
sort iso3 year
by iso3: gen gr_pwgdp_`s'=(pwgdp_`s'[_n]/pwgdp_`s'[_n-1])^(1/episode_length)-1
by iso3: gen grcont_pwgdp_wthn_`s'_share=((pwgdp_`s'[_n]-pwgdp_`s'[_n-1])*empl_share_`s'[_n-1])/(pwgdp_cons[_n]-pwgdp_cons[_n-1])
by iso3: gen grcont_pwgdp_srloc_`s'_share=((empl_share_`s'[_n]-empl_share_`s'[_n-1])*pwgdp_`s'[_n-1])/(pwgdp_cons[_n]-pwgdp_cons[_n-1])
by iso3: gen grcont_pwgdp_drloc_`s'_share=((empl_share_`s'[_n]-empl_share_`s'[_n-1])*(pwgdp_`s'[_n]-pwgdp_`s'[_n-1]))/(pwgdp_cons[_n]-pwgdp_cons[_n-1])

gen grcont_pwgdp_`s'_share=grcont_pwgdp_wthn_`s'_share+grcont_pwgdp_srloc_`s'_share+grcont_pwgdp_drloc_`s'_share
gen grcont_pwgdp_wthn_`s'=grcont_pwgdp_wthn_`s'_share*gr_pwgdp
gen grcont_pwgdp_srloc_`s'=grcont_pwgdp_srloc_`s'_share*gr_pwgdp
gen grcont_pwgdp_drloc_`s'=grcont_pwgdp_drloc_`s'_share*gr_pwgdp
gen grcont_pwgdp_`s'=grcont_pwgdp_`s'_share*gr_pwgdp
}
gen grcont_pwgdp_wthn_share= grcont_pwgdp_wthn_agr_share+grcont_pwgdp_wthn_ind_share+grcont_pwgdp_wthn_ser_share
gen grcont_pwgdp_srloc_share=grcont_pwgdp_srloc_agr_share+grcont_pwgdp_srloc_ind_share+grcont_pwgdp_srloc_ser_share
gen grcont_pwgdp_drloc_share=grcont_pwgdp_drloc_agr_share+grcont_pwgdp_drloc_ind_share+grcont_pwgdp_drloc_ser_share
gen grcont_pwgdp_wthn=grcont_pwgdp_wthn_agr+grcont_pwgdp_wthn_ind+grcont_pwgdp_wthn_ser
gen grcont_pwgdp_srloc=grcont_pwgdp_srloc_agr+grcont_pwgdp_srloc_ind+grcont_pwgdp_srloc_ser
gen grcont_pwgdp_drloc=grcont_pwgdp_drloc_agr+grcont_pwgdp_drloc_ind+grcont_pwgdp_drloc_ser

gen gdp_cons_lcu_adj=cpriv_cons_lcu+cgovt_cons_lcu+itotl_cons_lcu+exprt_cons_lcu-imprt_cons_lcu
gen grcont_gdp_cpriv=(cpriv_cons_lcu[_n]-cpriv_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_cgovt=(cgovt_cons_lcu[_n]-cgovt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_itotl=(itotl_cons_lcu[_n]-itotl_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_exprt=(exprt_cons_lcu[_n]-exprt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp
gen grcont_gdp_imprt=(-imprt_cons_lcu[_n]+imprt_cons_lcu[_n-1])/(gdp_cons_lcu_adj[_n]-gdp_cons_lcu_adj[_n-1])*gr_gdp

gen prodratio= ((va_ind_cons+va_ser_cons)/(pop_empl_ind+pop_empl_ser))/(va_agr_cons/pop_empl_agr)
gen wempl_pop=pop_empl*empl_share_wge
gen slfempl_pop=pop_empl*empl_share_slf
gen wtonw_ratio=wempl_pop/slfempl_pop

*additional variables
sort iso3 year
bysort iso3: gen pcgdp_index=100 if _n==1
bysort iso3: replace pcgdp_index=pcgdp_index[_n-1]*(1+gr_pcgdp[_n])^(episode_length) if _n>1
bysort iso3: gen er_index=1 if _n==1
bysort iso3: replace er_index=er_index[_n-1]*((er_lcuperusd[_n]/er_lcuperusd[_n-1])^(episode_length)) if _n>1
replace er_index=1/er_index
replace er_index=100*er_index
bysort iso3: replace er_reer=100 if _n==1
bysort iso3: replace er_reer=er_reer[_n-1]*((er_reer[_n]/er_reer[_n-1])^(episode_length)) if _n>1

bysort iso3: gen episode_start=year[_n-1]
bysort iso3: gen episode_end=year[_n] if episode_start!=.
egen episode=concat(episode_start episode_end) if episode_start!=., punct(-) 
bysort iso3: gen incstat_start=inc_class_hist[_n-1]
drop `w' `e' `p' `a'
save "$data\GrowthEpisode_short_global_$target_country.dta", replace

*Step2
****************************
*Historical Benchmarking Dataset
****************************
if "$target_country"!="all" {
use "$directory\Ancilliary Data\use_dataset.dta", clear
drop if pcgdp_cons_ppp_usd==.
keep if year>=1991
egen year_max=max(year) if year!=.
drop if year!=year_max-1 & iso3=="$target_country"
gen help1=pcgdp_cons_ppp_usd if year==year_max-1 & iso3=="$target_country"
egen target=min(help1)
drop help1
gen target_diff=abs(target-pcgdp_cons_ppp_usd)
egen target_diff_min=min(target_diff), by(iso3)
su pcgdp_cons_ppp_usd if iso3=="$target_country" & year==year_max-1
drop if target_diff>(r(mean)/10)
egen test1=rownonmiss(gdp_share_curr_agr gdp_share_curr_ind gdp_share_curr_ser va_agr_curr va_ind_curr va_ser_curr va_agr_cons va_ind_cons va_ser_cons cpriv_curr_lcu cpriv_cons_lcu cgovt_curr_lcu cgovt_cons_lcu itotl_curr_lcu itotl_cons_lcu imprt_curr_lcu imprt_cons_lcu exprt_curr_lcu exprt_cons_lcu cpriv_share_curr cgovt_share_curr itotl_share_curr imprt_share_curr exprt_share_curr pop pop_wap pop_active pop_empl pop_empl_agr pop_empl_ind pop_empl_ser empl_share_agr empl_share_ind empl_share_ser empl_rate ueml_rate lfp_rate wap_rate), strok
egen help1=max(test1), by(iso3)
keep if test1==help1
drop help1 test1 year_max
levelsof year if iso3=="$target_country", local(target_year)
sort iso3 year
by iso3: keep if _n==1
egen cyid=concat(iso3 year), p(-)
label var cyid "Country - Year ID"
tab cyid
save "$data\GlobalBenchmarking_$target_country.dta", replace

}
}

*Step3
****************************
*Define color scheme for figures
****************************

*Step2
grstyle init
grstyle color p1  "0 35 69"
grstyle color p2  "0 173 228"
grstyle color p3  "225 106 45"
grstyle color p4  "0 100 80"
grstyle color p5  "96 125 139"
grstyle color p6  "139 194 74"
grstyle color p7  "0 96 104"
grstyle color p8  "0 87 152"
grstyle color p9   "97 71 118"
grstyle color p10  "36 128 196"
grstyle color p11 "1 150 136"
grstyle color p12 "182 107 163"
grstyle color p13 "113 177 181"
grstyle color p14 "205 220 57"
disp _newline(100)  

*--------------------------------*--------------------------------*---------------------------------------
dis as result "THIS PROGRAM IS PART OF THE JOBS AND STRUCTURAL CHANGE STATA (JSCS) TOOL AND USES DATA FROM WDI AND PWT"
dis as text "For any questions, please contact: aeberhard@worldbank.org or dmerotto@worldbank.org"
*------------------------------*--------------------------------*----------------------------------------
disp _newline(2)  
if "$target_country"!="all" {
dis as result "The folder structure and the data for the Job Diagnostics Macro Analysis is now prepared." 
dis as result "National accounts data was drawn from the "`dataset'" dataset (GRO for Groeningen Structural Transformation Dataset and WDI for World Development Inidicators Dataset)." 
dis as result "  -> A global benchmarking dataset has been generated to compare "`target'"'s structural characteristics" 
dis as result "     in `target_year' with those typically observed at "`target'"'s current level of development." 
dis as result "  -> A growth episodes dataset has been generated to compare growth in "`target'" versus structural and" 
dis as result "     aspirational peers over the following yearly intervals $episodes." 
disp _newline(1)  
dis as result "To continue you have the following options:"
disp _newline(1)
dis as result "Option 1:"
dis as text  "Global benchmarking analysis of structural features of "`target'"'s economy. In the STATA Command Window below, please type:" 
disp as result "JSCS_benchmarking"
disp as text "and press enter."
disp _newline(1)
dis as result "Option 2:"
dis as text  "Growth episodes analysis for "`target'". In the STATA Command Window below, please type:"
disp as result "JSCS_episodes"
disp as text "and press enter."
disp _newline(1)
dis as result "Option 3:"
dis as text  "Growth episodes analysis for "`target'" versus structural and aspirational peers. In the STATA Command Window below, please type: "
disp as result "JSCS_comparisons"
disp as text "and press enter."
}
if "$target_country"=="all" {
dis as result "A global growth episodes dataset has been generated for the following intervals $episodes." 
disp _newline(1)
}

quietly {
clear
}

end				
