program WDI_update
disp _newline(100) 
dis as result "The WDI dataset for the Jobs Diagnostics Macro Analysis is being updated. This may take up to 10 minutes, please wait..."

quietly {
*******************
*National income
*******************
preserve
wbopendata, indicator(NY.GNP.MKTP.KN;NY.GNP.MKTP.CN;NY.GNP.MKTP.KD;NY.GNP.MKTP.CD;SP.POP.TOTL;NY.GNP.MKTP.PP.KD) long clear
drop if regionname=="Aggregates"
drop region regionname adminregion adminregionname incomelevel incomelevelname lendingtype lendingtypename
rename countryname country
rename countrycode iso3
rename ny_gnp_mktp_cn gni_curr_lcu
rename ny_gnp_mktp_kn gni_cons_lcu
rename ny_gnp_mktp_cd gni_curr_usd
rename ny_gnp_mktp_kd gni_cons_usd
gen pcgni_cons_usd=gni_cons_usd/sp_pop_totl
gen pcgni_curr_usd=gni_curr_usd/sp_pop_totl
gen pcgni_cons_usd_2017ppp=ny_gnp_mktp_pp_kd/sp_pop_totl
keep  country iso3 year pcgni_cons_usd pcgni_curr_usd pcgni_cons_usd_2017ppp gni_curr_lcu gni_cons_lcu gni_curr_usd gni_cons_usd
order country iso3 year pcgni_cons_usd pcgni_curr_usd pcgni_cons_usd_2017ppp gni_curr_lcu gni_cons_lcu gni_curr_usd gni_cons_usd 
sort country iso3 year
tempfile GNI_data
save `GNI_data'
restore
*******************
*GDP supply side
*******************
preserve
wbopendata, indicator(SP.POP.TOTL;NY.GDP.MKTP.CN;NY.GDP.MKTP.KN;NY.GDP.MKTP.CD;NY.GDP.MKTP.KD;NV.AGR.TOTL.CN;NV.IND.TOTL.CN;NV.SRV.TOTL.CN;NV.AGR.TOTL.KN;NV.IND.TOTL.KN;NV.SRV.TOTL.KN) long clear
drop if regionname=="Aggregates"
drop region regionname adminregion adminregionname incomelevel incomelevelname lendingtype lendingtypename
rename countryname country
rename countrycode iso3
rename ny_gdp_mktp_cn gdp_curr_lcu
rename ny_gdp_mktp_kn gdp_cons_lcu
rename ny_gdp_mktp_cd gdp_curr_usd
rename ny_gdp_mktp_kd gdp_cons_usd
rename nv_agr_totl_cn va_agr_curr
rename nv_ind_totl_cn va_ind_curr
rename nv_srv_totl_cn va_ser_curr
rename nv_agr_totl_kn va_agr_cons
rename nv_ind_totl_kn va_ind_cons
rename nv_srv_totl_kn va_ser_cons
gen gdp_share_curr_agr=va_agr_curr/(va_agr_curr+va_ind_curr+va_ser_curr)
gen gdp_share_curr_ind=va_ind_curr/(va_agr_curr+va_ind_curr+va_ser_curr)
gen gdp_share_curr_ser=va_ser_curr/(va_agr_curr+va_ind_curr+va_ser_curr)
gen gdp_share_cons_agr=va_agr_cons/(va_agr_cons+va_ind_cons+va_ser_cons)
gen gdp_share_cons_ind=va_ind_cons/(va_agr_cons+va_ind_cons+va_ser_cons)
gen gdp_share_cons_ser=va_ser_cons/(va_agr_cons+va_ind_cons+va_ser_cons)
drop va_agr_curr va_ind_curr va_ser_curr va_agr_cons va_ind_cons va_ser_cons  
gen va_agr_curr=gdp_curr_lcu*gdp_share_curr_agr
gen va_ind_curr=gdp_curr_lcu*gdp_share_curr_ind
gen va_ser_curr=gdp_curr_lcu*gdp_share_curr_ser
gen va_agr_cons=gdp_cons_lcu*gdp_share_cons_agr
gen va_ind_cons=gdp_cons_lcu*gdp_share_cons_ind
gen va_ser_cons=gdp_cons_lcu*gdp_share_cons_ser
order country iso3 year
keep country iso3 year gdp_cons* gdp_curr* va* gdp_share*
sort country iso3 year
tempfile GDP_data
save `GDP_data'
restore
*******************
*GDP expenditure side
*******************
preserve
wbopendata, indicator(NY.GDP.MKTP.CN;NE.CON.PRVT.CN;NE.CON.PRVT.KN;NE.CON.GOVT.CN;NE.CON.GOVT.KN;NE.GDI.FTOT.CN;NE.GDI.FTOT.KN;NE.IMP.GNFS.CN;NE.IMP.GNFS.KN;NE.EXP.GNFS.CN;NE.EXP.GNFS.KN;NE.GDI.FPRV.CN) long clear
drop if regionname=="Aggregates"
drop region regionname adminregion adminregionname incomelevel incomelevelname lendingtype lendingtypename
rename countryname country
rename countrycode iso3
rename ny_gdp_mktp_cn gdp_curr_lcu
rename ne_con_prvt_cn cpriv_curr_lcu
rename ne_con_prvt_kn cpriv_cons_lcu
rename ne_con_govt_cn cgovt_curr_lcu
rename ne_con_govt_kn cgovt_cons_lcu
rename ne_gdi_ftot_cn itotl_curr_lcu
rename ne_gdi_ftot_kn itotl_cons_lcu
rename ne_imp_gnfs_cn imprt_curr_lcu
rename ne_imp_gnfs_kn imprt_cons_lcu
rename ne_exp_gnfs_cn exprt_curr_lcu
rename ne_exp_gnfs_kn exprt_cons_lcu
rename ne_gdi_fprv_cn ipriv_curr_lcu
gen ipriv_cons_lcu=ipriv_curr_lcu/(itotl_curr_lcu/itotl_cons_lcu)
gen cpriv_share_curr=cpriv_curr_lcu/gdp_curr_lcu
gen cgovt_share_curr=cgovt_curr_lcu/gdp_curr_lcu
gen itotl_share_curr=itotl_curr_lcu/gdp_curr_lcu
gen imprt_share_curr=imprt_curr_lcu/gdp_curr_lcu
gen exprt_share_curr=exprt_curr_lcu/gdp_curr_lcu
order country iso3 year
keep country iso3 year c* itotl* imp* exp* ipriv*
sort country iso3 year
tempfile GDPexp_data
save `GDPexp_data'
restore
*******************
*Exchange rates
*******************
preserve 
wbopendata, indicator(PA.NUS.FCRF;PX.REX.REER;PA.NUS.PPP;NY.GDP.MKTP.PP.CD;NY.GDP.MKTP.PP.KD) long clear
drop if regionname=="Aggregates"
drop region regionname adminregion adminregionname incomelevel incomelevelname lendingtype lendingtypename
rename countryname country
rename countrycode iso3
rename pa_nus_fcrf er_lcuperusd
rename px_rex_reer er_reer
rename pa_nus_ppp ppp_cf
gen ppp_deflator=ny_gdp_mktp_pp_cd/ny_gdp_mktp_pp_kd
order country iso3 year
keep country iso3 year er* ppp_cf ppp_deflator
sort country iso3 year
tempfile exrate
save `exrate'
restore 
*******************
*Job market structure
*******************
preserve
wbopendata, indicator(SP.POP.TOTL;SP.POP.TOTL.MA.IN;SP.POP.TOTL.FE.IN;SP.POP.1564.TO.ZS;SP.POP.1564.MA.ZS;SP.POP.1564.FE.ZS;SP.POP.65UP.TO.ZS;SL.TLF.ACTI.ZS;SL.TLF.ACTI.MA.ZS;SL.TLF.ACTI.FE.ZS;SL.AGR.EMPL.ZS;SL.IND.EMPL.ZS;SL.SRV.EMPL.ZS;SL.UEM.TOTL.ZS;SL.UEM.TOTL.MA.ZS;SL.UEM.TOTL.FE.ZS) long clear
drop if regionname=="Aggregates"
drop region regionname adminregion adminregionname incomelevel incomelevelname lendingtype lendingtypename
rename countryname country
rename countrycode iso3
rename sp_pop_totl pop
rename sp_pop_totl_ma_in pop_ma
rename sp_pop_totl_fe_in pop_fe
rename sp_pop_1564_to_zs pop_share_1564
rename sp_pop_1564_fe_zs pop_share_1564_ma
rename sp_pop_1564_ma_zs pop_share_1564_fe
rename sp_pop_65up_to_zs pop_share_abv64
rename sl_tlf_acti_zs lfp_rate
rename sl_tlf_acti_ma_zs lfp_rate_ma
rename sl_tlf_acti_fe_zs lfp_rate_fe
rename sl_agr_empl_zs empl_share_agr
rename sl_ind_empl_zs empl_share_ind
rename sl_srv_empl_zs empl_share_ser
rename sl_uem_totl_zs ueml_rate
rename sl_uem_totl_ma_zs ueml_rate_ma
rename sl_uem_totl_fe_zs ueml_rate_fe
replace pop_share_1564=pop_share_1564/100
replace pop_share_abv64=pop_share_abv64/100
replace lfp_rate=lfp_rate/100
replace lfp_rate_ma=lfp_rate_ma/100
replace lfp_rate_fe=lfp_rate_fe/100
replace empl_share_agr=empl_share_agr/100
replace empl_share_ind=empl_share_ind/100
replace empl_share_ser=empl_share_ser/100
replace ueml_rate=ueml_rate/100
replace ueml_rate_ma=ueml_rate_ma/100
replace ueml_rate_fe=ueml_rate_fe/100
gen empl_rate=(1-ueml_rate)
gen empl_rate_ma=(1-ueml_rate_ma)
gen empl_rate_fe=(1-ueml_rate_fe)
gen wap_rate=pop_share_1564
gen wap_rate_ma=pop_share_1564_ma
gen wap_rate_fe=pop_share_1564_fe
gen pop_wap=pop*wap_rate
gen pop_wap_ma=pop*wap_rate_ma
gen pop_wap_fe=pop*wap_rate_fe
gen pop_active=pop*wap_rate*lfp_rate
gen pop_active_ma=pop_ma*wap_rate_ma*lfp_rate_ma
gen pop_active_fe=pop_fe*wap_rate_fe*lfp_rate_fe
gen pop_uempl=pop_active*(ueml_rate)
gen pop_empl=pop_active*(1-ueml_rate)
gen pop_empl_ma=pop_active_ma*(1-ueml_rate_ma)
gen pop_empl_fe=pop_active_fe*(1-ueml_rate_fe)
gen pop_empl_agr=pop_empl*empl_share_agr
gen pop_empl_ind=pop_empl*empl_share_ind
gen pop_empl_ser=pop_empl*empl_share_ser
replace pop_empl=pop_empl_agr+pop_empl_ind+pop_empl_ser
keep country iso3 year pop* pop_share* empl_* empl_rate* ueml_rate* lfp_rate* wap_rate*
order country iso3 year pop* pop_share* empl_* empl_rate* ueml_rate* lfp_rate* wap_rate*
sort country iso3 year
tempfile pop_data
save `pop_data'
restore
preserve
wbopendata, indicator(SL.EMP.WORK.ZS;SL.EMP.MPYR.ZS;SL.EMP.SELF.ZS;SL.EMP.VULN.ZS;SL.FAM.WORK.ZS) long clear
drop if regionname=="Aggregates"
drop region regionname adminregion adminregionname incomelevel incomelevelname lendingtype lendingtypename
rename countryname country
rename countrycode iso3
rename sl_emp_work_zs empl_share_wge
rename sl_emp_mpyr_zs empl_share_emp
rename sl_emp_self_zs empl_share_slf
rename sl_emp_vuln_zs empl_share_vln
rename sl_fam_work_zs empl_share_fml 
replace empl_share_wge=empl_share_wge/100
replace empl_share_emp=empl_share_emp/100
replace empl_share_slf=empl_share_slf/100
replace empl_share_vln=empl_share_vln/100
replace empl_share_fml=empl_share_fml/100
keep country iso3 year empl_*
order country iso3 year empl_*
sort country iso3 year
tempfile empltype_data
save `empltype_data'
restore
*******************
*Urbanization
*******************
preserve
wbopendata, indicator(NY.GNP.MKTP.CD;NY.GNP.MKTP.KD;SP.POP.TOTL;NY.GDP.MKTP.CN;NY.GDP.MKTP.KN;NY.GDP.MKTP.CD;NY.GDP.MKTP.KD;SP.URB.TOTL.IN.ZS;AG.LND.TOTL.UR.K2;EN.URB.MCTY.TL.ZS) long clear
drop if regionname=="Aggregates"
drop region regionname adminregion adminregionname incomelevel incomelevelname lendingtype lendingtypename
rename countryname country
rename countrycode iso3
rename sp_urb_totl_in_zs pop_share_urb
rename ag_lnd_totl_ur_k2 land_urb
rename en_urb_mcty_tl_zs pop_share_primcity
keep country iso3 year pop_share_urb land_urb pop_share_primcity
order country iso3 year pop_share_urb land_urb pop_share_primcity
tempfile urb_data
save `urb_data'
restore
*******************
*Poverty Rates
*******************
preserve
wbopendata, indicator(NY.GNP.MKTP.CD;NY.GNP.MKTP.KD;SP.POP.TOTL;NY.GDP.MKTP.CN;NY.GDP.MKTP.KN;NY.GDP.MKTP.CD;NY.GDP.MKTP.KD;SI.POV.DDAY;SI.POV.LMIC) long clear
drop if regionname=="Aggregates"
drop regionname adminregion adminregionname incomelevel incomelevelname lendingtype lendingtypename
rename countryname country
rename countrycode iso3
rename si_pov_dday hcp1
rename si_pov_lmic hcp2
replace hcp1=hcp1/100
replace hcp2=hcp2/100
keep country year iso3 region hcp1 hcp2
order country year iso3 region hcp1 hcp2
tempfile pov_data
save `pov_data'
restore
****************
*******************
*WB hist income classification
*******************
preserve
import excel "$directory\Ancilliary Data\WB income classification historical.xlsx", sheet("Sheet1") firstrow clear
reshape long yr, i(iso3) j(year)
rename yr inc_class_hist
replace inc_class_hist="HIC" if inc_class_hist=="H"
replace inc_class_hist="LIC" if inc_class_hist=="L"
replace inc_class_hist="LMIC" if inc_class_hist=="LM"
replace inc_class_hist="UMIC" if inc_class_hist=="UM"
replace inc_class_hist="LMIC" if inc_class_hist=="LM*"
replace inc_class_hist="" if inc_class_hist==".."
tempfile inc_class
save `inc_class'
restore 
*******************
*PWT
*******************
preserve
use "$directory\Ancilliary Data\pwt91.dta", clear
rename countrycode iso3
keep iso3 year emp avh rnna rtfpna xr
gen whours=emp*avh 
gen caps_pwt_rnna=1000000*rnna
rename rtfpna tfp
keep iso3 year whours caps_pwt_rnna tfp
tempfile pwt
save `pwt'
restore
********************
*Merge datasets
*********************
use `GNI_data', clear
merge 1:1 iso3 year using `GDP_data'
drop _merge
merge 1:1 iso3 year using `GDPexp_data'
drop _merge
merge 1:1 iso3 year using `exrate'
drop _merge
merge 1:1 iso3 year using `pop_data'
drop _merge
merge 1:1 iso3 year using `empltype_data'
drop _merge
merge 1:1 iso3 year using `urb_data'
drop _merge
merge 1:1 iso3 year using `pov_data'
drop _merge
merge 1:1 iso3 year using `inc_class'
drop if _merge==2
drop _merge
merge 1:1 iso3 year using `pwt'
drop if _merge==2
drop _merge

gen gdp_deflator_lcu=gdp_curr_lcu/gdp_cons_lcu
gen help1=gdp_deflator_lcu if year==2011
egen base_2011=min(help1), by(iso3)
gen gdp_deflator_2011=gdp_deflator_lcu/base_2011
drop help1 base_2011 gdp_deflator_2011

gen gdp_ppp_curr_usd=gdp_curr_lcu/ppp_cf
gen gdp_ppp_cons_usd=(gdp_curr_lcu/ppp_cf)/ppp_deflator
gen pcgdp_cons_ppp_usd=gdp_ppp_cons_usd/pop

sort iso3 year
order country iso3 year inc_class_hist
save "$directory\Ancilliary Data\WDI_JSCS_dataset.dta", replace
}

quietly {
cd "$directory\Ancilliary Data\Groeningen Data\"
local grofile : dir . files `"*"'
disp `grofile'
use `grofile', clear
rename cnt iso3
egen ind=rowtotal(min man pu con), missing
gen ser=tot-agr-ind
keep iso3 year var agr ind ser tot
replace var="va" if var=="VA"
replace var="pop_empl" if var=="EMP"
replace var="va_cons" if var=="VA_Q15"
reshape wide agr ind ser tot, i(iso3 year) j(var) string
rename totpop_empl pop_empl
rename agrpop_empl pop_empl_agr
rename indpop_empl pop_empl_ind
rename serpop_empl pop_empl_ser
rename totva gdp_curr_lcu
rename agrva va_agr_curr
rename indva va_ind_curr
rename serva va_ser_curr
rename totva_cons gdp_cons_lcu
rename agrva_cons va_agr_cons
rename indva_cons va_ind_cons
rename serva_cons va_ser_cons

gen defl_gdp=gdp_curr_lcu/gdp_cons_lcu
gen defl_agr=va_agr_curr/va_agr_cons
gen defl_ind=va_ind_curr/va_ind_cons
gen defl_ser=va_ser_curr/va_ser_cons

gen help1=defl_gdp if year==2010
gen help2=defl_agr if year==2010
gen help3=defl_ind if year==2010
gen help4=defl_ser if year==2010

egen defl_base_gdp=min(help1), by(iso3)
egen defl_base_agr=min(help2), by(iso3)
egen defl_base_ind=min(help3), by(iso3)
egen defl_base_ser=min(help4), by(iso3)

gen defl_gdp_10= defl_gdp/defl_base_gdp
gen defl_agr_10= defl_agr/defl_base_agr
gen defl_ind_10= defl_ind/defl_base_ind
gen defl_ser_10= defl_ser/defl_base_ser

replace gdp_cons_lcu=gdp_curr_lcu/defl_gdp_10
replace va_agr_cons=va_agr_curr/defl_agr_10
replace va_ind_cons=va_ind_curr/defl_ind_10
replace va_ser_cons=va_ser_curr/defl_ser_10

rename defl_gdp_10 gdp_deflator_lcu

gen empl_share_agr=pop_empl_agr/pop_empl
gen empl_share_ind=pop_empl_ind/pop_empl
gen empl_share_ser=pop_empl_ser/pop_empl

gen gdp_share_curr_agr=va_agr_curr/gdp_curr_lcu
gen gdp_share_curr_ind=va_ind_curr/gdp_curr_lcu
gen gdp_share_curr_ser=va_ser_curr/gdp_curr_lcu

gen gdp_share_cons_agr=va_agr_cons/gdp_cons_lcu
gen gdp_share_cons_ind=va_ind_cons/gdp_cons_lcu
gen gdp_share_cons_ser=va_ser_cons/gdp_cons_lcu

keep iso3 year pop* gdp* va_agr* va_ind* va_ser* gdp_deflator_lcu empl_share_* gdp_share_curr_* gdp_share_cons_*
order iso3 year pop* gdp* va_agr* va_ind* va_ser* gdp_deflator_lcu empl_share_* gdp_share_curr_* gdp_share_cons_*

save "$directory\Ancilliary Data\GRO_JSCS_dataset.dta", replace
}

display _newline(100)

dis as result "The WDI dataset for the Jobs and Structural Change Stata Tool has been successfully updated."

 

end